#
# spec file for package resource-agents
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           resource-agents
Version:        4.13.0+git41.828c175c
Release:        1.1
Summary:        HA Reusable Cluster Resource Scripts
License:        GPL-2.0-only AND LGPL-2.1-or-later AND GPL-3.0-or-later
Group:          Productivity/Clustering/HA
URL:            http://linux-ha.org/
Source:         resource-agents-%{version}.tar.xz
Source1:        monitoring-plugins-metadata.tar.bz2

# PATCH-FIX-OPENSUSE: activate VG with partial PV by default
Patch1:         0001-LVM-Default-partial_activation-to-true-in-SLE-HAE.patch
# PATCH-FIX-OPENSUSE: fix path to sm-notify
Patch2:         0002-nfsserver-fix-path-to-sm-notify.patch
# PATCH-FIX-OPENSUSE: ldirectord: don't create subsys lock
Patch3:         0003-ldirectord-don-t-create-subsys-lock.patch
# PATCH-FIX-OPENSUSE: Revert moving binaries to /usr/libexec
Patch4:         0004-Revert-Low-build-Move-binaries-in-usr-lib-heartbeat-.patch
# PATCH-FIX-OPENSUSE: Revert ocf_log: use same log format at pacemaker
Patch6:         0006-Revert-ocf_log-use-same-log-format-as-pacemaker.patch
# PATCH-FIX-OPENSUSE:
Patch7:         0007-Request-to-add-gcp-vpc-move-route.patch

Patch8:         nfsnotify.patch
Patch9:         portblock.patch

# PATCH-FIX-OPENSUSE: Remove deprecated perl-IO-Socket-INET6 dependency
Patch10:        resource-agents-deprecate-INET6.patch

BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  cluster-glue-devel
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  docbook_4
BuildRequires:  libqb-devel
BuildRequires:  libxslt
BuildRequires:  pkgconfig
BuildRequires:  systemd-rpm-macros
BuildRequires:  pkgconfig(glib-2.0)
Requires:       /usr/bin/logger
Obsoletes:      heartbeat-resources
Provides:       %{name}-devel = %{version}
Provides:       heartbeat-resources
# Merging the aws-vpc-move-ip package as the upstream RA will be adopted.
Provides:       aws-vpc-move-ip = 0.2.20171113
Obsoletes:      aws-vpc-move-ip <= 0.2.20171113
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
A set of scripts to interface with several services to operate in a
High Availability environment for both Pacemaker and rgmanager
service managers.

%package zfs
Summary:        resource-agent for ZFS support
License:        GPL-2.0-only AND LGPL-2.1-or-later AND GPL-3.0-or-later
Group:          Productivity/Clustering/HA
Requires:       %{name}
Provides:       %{name}:%{_mandir}/man7/ocf_heartbeat_ZFS.*
Provides:       %{name}:%{_prefix}/lib/ocf/resource.d/heartbeat/ZFS

%package -n ldirectord
Summary:        A Monitoring Daemon for Maintaining High Availability Resources
License:        GPL-2.0-only AND LGPL-2.1-or-later
Group:          Productivity/Clustering/HA
Requires:       %{name}
Requires:       ipvsadm
Requires:       logrotate
Requires:       perl-IO-Socket-IP
Requires:       perl-MailTools
Requires:       perl-Net-SSLeay
Requires:       perl-Socket6
Requires:       perl-libwww-perl
Obsoletes:      heartbeat-ldirectord
Provides:       heartbeat-ldirectord
%{?systemd_requires}

%description zfs
Containing the resource agent and documentation for ZFS support

%description -n ldirectord
ldirectord is a stand-alone daemon for monitoring the services on real
servers. Currently, HTTP, HTTPS, and FTP services are supported.
ldirectord works with the heartbeat code (http://www.linux-ha.org/).

See `ldirectord -h` and linux-ha/doc/ldirectord for more information.

%package -n monitoring-plugins-metadata
Summary:        Metadata for Monitoring plugins
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          Productivity/Clustering/HA
Requires:       monitoring-plugins-fping
Requires:       monitoring-plugins-http
Requires:       monitoring-plugins-ldap
Requires:       monitoring-plugins-mysql
Requires:       monitoring-plugins-pgsql
Requires:       monitoring-plugins-tcp
Requires:       resource-agents
Provides:       nagios-plugins-metadata
BuildArch:      noarch

%description -n monitoring-plugins-metadata
XML files containing metadata which facilitates using nagios
plugins as resource agents. These files were produced from help
pages of individual nagios plugins.

%prep
%setup -q
%patch -P 1 -p1
%patch -P 2 -p1
%patch -P 3 -p1
%patch -P 4 -p1
%patch -P 6 -p1
%patch -P 7 -p0
%patch -P 8 -p0
%patch -P 9 -p0
%patch -P 10 -p1

%build
autoreconf -fvi
# because quilt push changed the permissions of  sg_persist.
# chmod 775 heartbeat/sg_persist
%configure \
    --docdir=%{_defaultdocdir}/%{name} \
    --with-ras-set=linux-ha \
    --enable-fatal-warnings=no \
    --enable-libnet=no \
    --with-systemdsystemunitdir=%{_unitdir} \ \
    --with-pkg-name=%{name} \
    --with-rsctmpdir=%{_rundir}/%{name}
make %{?_smp_mflags}

%install
%make_install
mkdir -p %{buildroot}%{_sysconfdir}/ha.d/resource.d
ln -s service %{buildroot}/%{_sbindir}/rcldirectord
# Dont package static libs
find %{buildroot} -type f -name "*.la" -delete -print
# Unset execute permissions from things that shouln't have it
find %{buildroot} "(" -name "ocf-*" -o -name "*.dtd" ")" -type f -exec chmod a-x "{}" "+"
chmod 0755 %{buildroot}%{_sbindir}/ocf-tester
chmod 0755 %{buildroot}%{_sbindir}/ocft
mkdir -p %{buildroot}%{_prefix}/lib/tmpfiles.d
install -m 644 systemd/resource-agents.conf %{buildroot}%{_prefix}/lib/tmpfiles.d

(
cd %{buildroot}/%{_libdir}/heartbeat
for f in ocf-returncodes ocf-shellfuncs
do
    ln -s %{_prefix}/lib/ocf/lib/heartbeat/$f
done
)

# install nagios plugins XML metadata
tar -xjf %{SOURCE1}
mkdir -p %{buildroot}%{_datadir}/nagios/plugins-metadata
for file in $(find plugins-metadata -type f); do
	install -m 644 $file %{buildroot}%{_datadir}/nagios/plugins-metadata
done

# Create a symlink for backward compat of suse:aws-vpc-move-ip
(
mkdir -p %{buildroot}%{_prefix}/lib/ocf/resource.d/suse
cd %{buildroot}%{_prefix}/lib/ocf/resource.d/suse
ln -s %{_prefix}/lib/ocf/resource.d/heartbeat/aws-vpc-move-ip aws-vpc-move-ip
)

%if %{suse_version} >= 1600
%python3_fix_shebang_path %{buildroot}%{_prefix}/lib/ocf/resource.d/heartbeat/*
%endif

%post
%service_add_post resource-agents-deps.target
%tmpfiles_create %_tmpfilesdir/resource-agents.conf

%preun
%service_del_preun resource-agents-deps.target

%postun
%service_del_postun resource-agents-deps.target

%pre
%service_add_pre resource-agents-deps.target

%preun -n ldirectord
%service_del_preun ldirectord.service

%postun -n ldirectord
%service_del_postun ldirectord.service

%post -n ldirectord
%service_add_post ldirectord.service

%pre -n ldirectord
%service_add_pre ldirectord.service

%files
%defattr(-,root,root)
%dir %{_prefix}/lib/ocf
%dir %{_prefix}/lib/ocf/resource.d
%dir %{_prefix}/lib/ocf/lib
%dir %{_prefix}/lib/tmpfiles.d
%_tmpfilesdir/resource-agents.conf
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/*.rng
%dir %{_datadir}/%{name}/ocft
%dir %{_datadir}/%{name}/ocft/configs
%config(noreplace) %{_datadir}/%{name}/ocft/configs/*
%{_datadir}/%{name}/ocft/caselib
%{_datadir}/%{name}/ocft/README
%{_datadir}/%{name}/ocft/README.zh_CN
%{_datadir}/%{name}/ocft/helpers.sh
%{_datadir}/%{name}/ocft/runocft
%{_datadir}/%{name}/ocft/runocft.prereq
%{_prefix}/lib/ocf/resource.d/suse
%{_prefix}/lib/ocf/resource.d/heartbeat
%exclude %{_prefix}/lib/ocf/resource.d/heartbeat/ZFS
%{_prefix}/lib/ocf/lib/heartbeat
%{_sbindir}/ocf-tester
%{_sbindir}/ocft
%{_sbindir}/sfex_init
%{_sbindir}/sfex_stat
%{_includedir}/heartbeat
%{_unitdir}/resource-agents-deps.target
%ghost %dir %attr (1755, root, root) %{_rundir}/resource-agents
%doc AUTHORS
%license COPYING
%license COPYING.LGPL
%license COPYING.GPLv3
%doc %{_datadir}/%{name}/ra-api-1.dtd
%{_mandir}/man7/*.7*
%exclude %{_mandir}/man7/ocf_heartbeat_ZFS.*
%{_mandir}/man8/ocf-tester.8*
%{_mandir}/man8/sfex_init.8*
%doc doc/README.webapps
# For compatability with pre-existing agents
%dir %{_sysconfdir}/ha.d
%config %{_sysconfdir}/ha.d/shellfuncs
%dir %{_libdir}/heartbeat
%{_libdir}/heartbeat/*
%{_datadir}/pkgconfig/resource-agents.pc

%files zfs
%{_prefix}/lib/ocf/resource.d/heartbeat/ZFS
%{_mandir}/man7/ocf_heartbeat_ZFS.*

%files -n ldirectord
%defattr(-,root,root)
%doc ldirectord/ldirectord.cf
%{_mandir}/man8/ldirectord.8*
%dir %{_sysconfdir}/ha.d/resource.d
%{_sbindir}/ldirectord
%{_sbindir}/rcldirectord
%{_unitdir}/ldirectord.service
%exclude %{_sysconfdir}/init.d/ldirectord
%{_sysconfdir}/ha.d/resource.d/ldirectord
%config(noreplace) %{_sysconfdir}/logrotate.d/ldirectord

%files -n monitoring-plugins-metadata
%defattr(-,root,root)
%dir %{_datadir}/nagios
%dir %{_datadir}/nagios/plugins-metadata
%attr(0644,root,root) %{_datadir}/nagios/plugins-metadata/*

%changelog
* Fri Apr  5 2024 varkoly@suse.com
- Update to version 4.13.0+git41.828c175c:
  * Fix: openstack-info: Ensure no newlines in openstack_ports
  * nfsserver: fix "server scope" functionality for both potentially other dropins AND multiple ExecStart
  * all agents: remove -S state/status that are either ignored, or give an error message in newer versions of Pacemaker
  * portblock: accept numeric protocol from iptables
  * spec: use /usr/sbin paths for Fedora 40+
  * Support IPv6 with Azure load balncer. Using the  "TCP6-LISTENER" causes socat to listen in a dual-stack manner (bsc#1220997)
  * Doc: Delay: Drop old comments
  * Fix docker RA behavior when Docker isn't running
  * galera: allow joiner to report non-Primary during initial IST
* Tue Mar 12 2024 pgajdos@suse.com
- remove dependency on /usr/bin/python3 using
  %%python3_fix_shebang_path macro, [bsc#1212476]
* Fri Feb 16 2024 varkoly@suse.com
- Update to version 4.13.0+git23.fa8a56f6:
  * Don't build with -ansi by default
  * Filesystem: add reference to wait manpage to comment
  * Avoid false positive for VG activation
  * configure: fix "C preprocessor "gcc -E" fails sanity check" error caused by autoconf 2.72
  * Low: IPaddr2: Remove stray backslash
  * storage_mon: use memset() to fix "uninitialized value" covscan error, as qb_ipcc_recv() will always set a message (according to honzaf)
  * findif: also check that netmaskbits != EOS
  * storage_mon: fix file handler out of scope leak and uninitialized values
  * aws-vpc-move-ip/aws-vpc-route53/awseip/awsvip: add auth_type parameter and AWS Policy based authentication type
* Mon Jan 15 2024 Pedro Monreal <pmonreal@suse.com>
- Remove the deprecated perl-IO-Socket-INET6 dependency
  * Remove the dependency on perl(IO::Socket::INET6) as it has been
    deprecated by upstream, is no longer suitable for use and its not
    being maintained. A compatible replacement for this package is
    perl(IO::Socket::IP) which is shipped by the perl-base package.
  * Add resource-agents-deprecate-INET6.patch
* Tue Nov 14 2023 varkoly@suse.com
- Update to version 4.13.0+git6.ae50f94f:
  * findif.sh: fix loopback handling
  * exportfs: remove test for "fsid=" parameter
  * Fix PRIMARY_IFACE variable. In some cases ip returns two lines
  * build: update ChangeLog for 4.13.0
  * README: update IRC info to link to ClusterLabs wiki IRC page
  * findif.sh: dont use table parameter as it returns no netmask (tested with main/local/custom tables)
  * build: update ChangeLog for 4.13.0-rc1
  * iSCSI: add support for scst
  * Low: storage-mon: Remove unnecessary code and fix typos.
  * mysql-common: improve error message (#1887)
  * Mid: storage-mon RA: Changed OCF_RESKEY_daemonize_default and OCF_RESKEY_daemonize default and judgment part.
  * postfix: Update permission check from su to runuser/su (#1880)
  * Mid: storage-mon: Retry failed attrd_updater.
  * Mid: storage-mon: Added daemon/client mode.
  * Mid: storage-mon: Functionalization of test_device call processing.
* Tue Jul 25 2023 varkoly@suse.com
- Update to version 4.12.0+git50.5c26404e:
  * Filesystem: fix incorrect variable name for signal_delay default in metadata
  * Delay: remove statement about defaulting to "startdelay" value if not specified
  * Filesystem: dont use boolean type for non-boolean parameters
  * Filesystem: list_mounts: fix mount command output parsing
  * Delay: increase stop, status and monitor timeouts to 40s to avoid failing with default values
  * Filesystem: improve stop-action and allow setting term/kill signals and signal_delay for large filesystems
  * findif.sh: fix table parameter so it uses main table by default
  * mysql: fix promotion_score bouncing between ~3600 and 1 on demoted nodes
  * spec: Migrate to SPDX license
  * Filesystem: create systemd drop-in for network filesystems
* Mon May  1 2023 varkoly@suse.com
- Update to version 4.12.0+git30.7fd7c8fa:
  * Filesystem: fail if AWS efs-utils not installed when fstype=efs
  * azure-events*: Use -LS instead of -Ls as parameter to get the Transition Summary (#1864)
  * spec: remove JFLAGS logic and use %%{_smp_mflags} like we do in other projects
  * exportfs: make the "fsid=" parameter optional
  * nfsserver: prepare the layout for the default /var/lib/nfs
  * IPv6addr: expect ping/pong delay
  * azure-events*: fix for no "Transition Summary" for Pacemaker 2.1+
  * ZFS: add non-blocking check if pool was imported (#1853)
  * ethmonitor: dont log "Interface does not exist" for monitor-action
  * mysql: promotable fixes to avoid nodes getting bounced around by setting -v 1/-v 2, and added OCF_CHECK_LEVEL=10 for promotable resources to be able to distinguish between promoted and not
  * LVM-activate: failover with missing PVs
* Thu Mar 16 2023 varkoly@suse.com
- Update to version 4.12.0+git10.fe1a2f88:
  * Mid: ocf-shellfuncs: Explicitly specify $OCF_RESOURCE_INSTANCE in the p parameter for compatibility.
  * nfsserver: fix "server scope" functionality to live with additional drop-in files
  * pgsql: dont run promotable and file checks that could be on shared storage during validate-all action
  * exportfs: move testdir() to start-action to avoid failing during resource creation (validate-all) and make it create the directory if it doesnt exist
* Wed Jan 25 2023 Peter Varkoly <varkoly@suse.com>
- Update to version 4.12.0+git3.5c81805c:
  * db2: avoid eval with unsanitized values (#1838) (bsc#1146789)
  * build: update ChangeLog for 4.12.0
  * build: update ChangeLog for 4.12.0-rc1
  * README: update IRC info (#1835)
  * CTDB: change public_addresses validate-all warning to info
  * Filesystem: remove validate-all mountpoint warning as it is auto-created during start-action if it doesnt exist
  * galera/mpathpersist/sg_persist/IPsrcaddr: only check notify and promotable when OCF_CHECK_LEVEL=10
  * WAS6: fix trap condition
  * exportfs: fix the error handling during monitoring
  * IPaddr2/IPsrcaddr: add/modify table parameter to be able to find interface while using policy based routing
* Wed Dec 14 2022 varkoly@suse.com
- Update to version 4.11.0+git90.c1dd3806:
  * Please don't suggest /tmp/mysql-proxy.sock, that is bad practice. Use one of the directories where this socket can be provided securely
    (bsc#1146768)
  * SAPInstance: be more resilient against broken kill.sap files (#1825)
    (bsc#1206100)
  * lvmlockd: add "use_lvmlockd = 1" if it's commented out or missing
  * nfsserver: add nfsv4_only parameter to make it run without rpc-statd/rpcbind services
  * mysql-common: return error in stop-action if kill fails to stop the process so the node can get fenced
  * configure.ac: Fix bashisms
  * docker/podman/zabbixserver:replace error log messages with calls to ocf_exit_reason
  * vdo-vol: don't fail probe action when the underlying device doesn't exist
  * build: add iface-macvlan
  * iface-macvlan: new resource agent (#1815)
* Wed Nov 30 2022 Peter Varkoly <varkoly@suse.com>
- Remove ocf_heartbeat_ZFS (bsc#1205556)
  A new package resource-agents-zfs will contain ZFS support, which will not be shipped on SLES.
* Tue Oct 25 2022 Peter Varkoly <varkoly@suse.com>
- Impl: AWS EFS Support in Filesystem OCF required (jsc#PED-1934)
  Update to version 4.11.0+git72.c1f0a07e:
  * IPsrcaddr: fix monitor/status for default route not being equal to src IP before start, and change route src correctly in stop-action
  * IPsrcaddr: use scope host when using non-main tables
  * IPsrcaddr: detect metric for main table only, and allow specifying metric if necessary
  * IPsrcaddr: fix PROTO regex
  * dev-guide: Correct default branch name
  * galera/mariadb/mpathpersist/mysql/pgsql/sg_persist/Stateful: use ocf_promotion_score() to avoid issues with deprecated crm_master
  * ocf-shellfuncs: add ocf_promotion_score() to use crm_attribute -p/crm_master depending on Pacemaker version
  * portblock: implement blocking of outgoing ports
  * VirtualDomain: replace error log messages with calls to ocf_exit_reason
  * ocf-tester: remove removed parameter -L from Usage text
  * storage_mon: improve error messages when ioctl() fails
  * storage_mon: do random lseek even with O_DIRECT, etc
  * storage_mon: fix build-related issues
  * storage_mon: Use the O_DIRECT flag in open() to eliminate cache effects
  * CTDB: move process to root cgroup if realtime scheduling is enabled
  * ethmonitor/ovsmonitor/pgsql: remove ignored attrd_updater "-q" parameter
  * Fix bug in handling of child process exit.
  * storage_mon: Fix bug in checking of number of specified scores.
  * storage_mon: make -h exit just after printing help message (#1791)
  * ocf-tester: remove deprecated lrmd/lrmadmin code that hasnt worked since pre-pacemaker days
  * openstack-agents: set domain parameter's default to Default and fix missing parameter name in ocf_exit_reason
  * ocf-tester: use promotable terms
  * openstack-agents: warn when openstackcli is slow
  * openstack-agents: fixes
  * mariadb: Remove obsolete DEBUG_LOG functionality #1191
  * configure/spec: remove google-api-client BuildReq as the gcp-agents build fine without it
  * LVM-activate: Fix return codes
  * metadata: update to promoted roles
  * all agents: update to promotable terms
  * spec: use cluster-glue-devel for opensuse > 15
  * azure-events-az: new resource agent (#1774)
  * lvmlockd: fail when use_lvmlockd has not been set
  * dnsupdate: add CNAME support (#1773)
  * aws-vpc-move-ip: Allow to set the interface label
  * Do not mkdir -p when getting meta-data or help
  * iSCSILogicalUnit: fix issue where resource was in stopped state when using allowed_initiators parameter (#1766)
  * oracle: Improve the error message if monpassword was not set. (#1767)
  * spec: remove redhat-lsb-core dependency (lsb_release)
  * podman: add podman parameter error judgment (#1764)
  * ethmonitor,ovsmonitor,mariadb: check for bc binary
  * ocivip: fix spelling errors
  * Filesystem: improve logic for UUID/label and add note that /dev/disk/by-{uuid,label}/ are preferred on Linux
  * docker-compose: fix number of containers/running containers logic
  * iSCSILogicalUnit: fix issue where resource was in stopped state when using allowed_initiators parameter (#1766)
  * Filesystem: improve logic for UUID/label and add note that /dev/disk/by-{uuid,label}/ are preferred on Linux
  * oracle: Improve the error message if monpassword was not set. (#1767)
  * spec: remove redhat-lsb-core dependency (lsb_release)
  * podman: add podman parameter error judgment (#1764)
  * ethmonitor,ovsmonitor,mariadb: check for bc binary
  * ocivip: fix spelling errors
  * build: update ChangeLog for 4.11.0
  * storage-mon,ldirectord: fix spelling errors
  * db2: fix bashism
  * openstack-info: fix bashism
  * Filesystem: fix logic for UUID/label devices with space between parameter and UUID/label
  * build: update ChangeLog for 4.11.0-rc1
  * ocf-distro: improve RHEL based distro detection
  * ipsec: fix check string against another string not the before defined variable (#1755)
  * spec: fix mount.cifs if
  * LVM-activate:change lvm_status return value from ocf_not_running to ocf_err_generic (#1753)
  * IPaddr2: Clarify behavior of 'arp_*' parameters for IPv4 and IPv6
  * IPaddr2: Log 'ip addr add' options together
  * IPaddr2: Allow to send IPv6 Neighbor Advertisements in background
  * IPaddr2: Allow to disable Duplicate Address Detection for IPv6
  * ocivip: new resource agent (#1751)
  * corosync-qnetd: Add resource agent
  * ocf-shellfuncs: quote pid in ocf_pidfile_status
  * IPsrcaddr: fixes
  * db2: only warn when notify isnt set, and use ocf_local_nodename() to get node name
  * IPsrcaddr: fix indentation in better error message code
  * IPsrcaddr: Better error message when no matching route found
  * IPsrcaddr: Add warning about DHCP
  * ocf-shellfuncs: Parametrise the log destinarion by OCF_RESKEY_trace_dir
  * rabbitmq-server-ha: Use ocf_is_true, if applicable
  * Fix SERVER_START_ARGS sname/name use for FQDN
  * LinuxSCSI:replace error log messages with calls to ocf_exit_reason
  * Filesystem: Add support for Amazon EFS mount helper
  * Filesystem: Improve fstype_supported logs for fuse
  * Filesystem: Fix OpenBSD check in fstype_supported()
  * openstack agents: align timeout also for monitoring operation
  * mysql-common: fix local SSL connection by using --ssl-mode=REQUIRED which is available on 5.7+ (--ssl is not available in 8.0)
  * openstack-common: get_config(): expand tilde and exit for errors
  * openstack-*: hardcode clouds.yaml paths as openstack cli doesnt support overriding it
  * openstack-*: add support for multiple setup options
  * LVM-activate: replace error log messages with calls to ocf_exit_reason (#1730)
  * configure: fix typo (#1732)
  * build: workaround gcc 12 warning
  * openstack-info: align op timeout with other openstack agents
  * openstack-*: allow agents to perform insecure connections to openstackcli
  * Route: return OCF_NOT_RUNNING for probe action when interface or route doesnt exist
  * podman: remove anonymous volumes
  * asterisk: Sipsak check fix (#1716)
  * [rpm] fix Requires to allow install on opensuse
  * Filesystem: unmount bind mounts before unmount file system
  * db2: use -l forever instead of -t nodes -l reboot, as they conflict with eachother
  * nginx: replace error log messages with calls to ocf_exit_reason
  * rabbitmq-server-ha: Revert "OCF RA: Do not start rabbitmq if notification of start is not about us" (#1713)
  * asterisk: fix sipsak check during start-action (#1715)
  * rabbitmq-server-ha: Avoid forget_cluster_node without node name
  * gcp-ilb: only check if log_cmd binary is available if log_enable is true
  * rabbitmq-server-ha: use "s"-suffix for timeouts/intervals
  * rabbitmq-server-ha: rename and add to Makefiles
  * nvmet-subsystem: fix allowed_initiators for to avoid only running once (found by shellcheck)
  * gcp-ilb/Squid: fix issues detected by CI
  * configure: only run ci/build.sh when shellcheck is present
  * RabbitMQ OCF RA M/S HA cluster agent migration (#1698)
  - Adjust BuildRequire libglue-devel -> cluster-glue-devel.
  - Drop obs resource-agents.conf and reuse the one in upstream commit 826c5532
  - Remove patches contained by the new version:
    0002-IPaddr2-Allow-to-send-IPv6-Neighbor-Advertisements-i.patch
    0001-mariadb-Remove-obsolete-DEBUG_LOG-functionality-1191.patch
    0001-Improve-the-error-message-if-monpassword-was-not-set.patch
    0004-IPaddr2-Clarify-behavior-of-arp_-parameters-for-IPv4.patch
    0001-aws-vpc-move-ip-Allow-to-set-the-interface-label.patch
    0003-IPaddr2-Log-ip-addr-add-options-together.patch
    0001-IPaddr2-Allow-to-disable-Duplicate-Address-Detection.patch
* Wed Jul  6 2022 Peter Varkoly <varkoly@suse.com>
- AUDIT-FIND: resource-agents: Predictable log file in /tmp in mariadb.in
  (bsc#1146691)
  Add patch:
    0001-mariadb-Remove-obsolete-DEBUG_LOG-functionality-1191.patch
* Thu Jun  9 2022 Peter Varkoly <varkoly@suse.com>
- RA aws-vpc-move-ip is lacking the possibility to assign a label to an interface.
  (bsc#1199766)  Include upsteam patch:
  0001-aws-vpc-move-ip-Allow-to-set-the-interface-label.patch
- Can IPaddr2 run ARP for IPV6 in background during start operation
  (bsc#1196164)
  Include upstream patches:
  0001-IPaddr2-Allow-to-disable-Duplicate-Address-Detection.patch
  0002-IPaddr2-Allow-to-send-IPv6-Neighbor-Advertisements-i.patch
  0003-IPaddr2-Log-ip-addr-add-options-together.patch
  0004-IPaddr2-Clarify-behavior-of-arp_-parameters-for-IPv4.patch
* Sun May  1 2022 Peter Varkoly <varkoly@suse.com>
- oracle RA lists monpassword as optional but fails unless provided
  (bsc#1197956)
  Add upstream patch:
    0001-Improve-the-error-message-if-monpassword-was-not-set.patch
* Wed Jan 19 2022 Peter Varkoly <varkoly@suse.com>
- nfs ganehsa failover takes 5 minutes for the client to regain
  access to nfs share (bsc#1184382)
  - add adapted proposed patches
    portblock.patch nfsnotify.patch
- Update to version 4.10.0+git40.0f4de473:
  * openstack-common: get_config(): expand tilde and exit for errors
  * openstack-*: hardcode clouds.yaml paths as openstack cli doesnt support overriding it
  * openstack-*: add support for multiple setup options
  * LVM-activate: replace error log messages with calls to ocf_exit_reason (#1730)
  * configure: fix typo (#1732)
  * build: workaround gcc 12 warning
  * openstack-info: align op timeout with other openstack agents
  * openstack-*: allow agents to perform insecure connections to openstackcli
  * Route: return OCF_NOT_RUNNING for probe action when interface or route doesnt exist
  * podman: remove anonymous volumes
* Tue Dec  7 2021 varkoly@suse.com
- Update to version 4.10.0+git22.a614b31c:
  * asterisk: Sipsak check fix (#1716)
  * [rpm] fix Requires to allow install on opensuse (#1721)
  * Filesystem: unmount bind mounts before unmount file system (jsc#SLE-21043)
  * db2: use -l forever instead of -t nodes -l reboot, as they conflict with eachother
  * nginx: replace error log messages with calls to ocf_exit_reason
* Tue Nov 23 2021 varkoly@suse.com
  Update from 4.8.0 to 4.10.0 contains fix of following issues:
  bsc#1151833 bsc#1154465 bsc#1170270 bsc#1172734 bsc#1180668
  bsc#1184382 bsc#1186652
- Update to version 4.10.0+git13.7263a78d:
  * rabbitmq-server-ha: Revert "OCF RA: Do not start rabbitmq if notification of start is not about us" (#1713)
  * asterisk: fix sipsak check during start-action (#1715)
  * rabbitmq-server-ha: Avoid forget_cluster_node without node name
  * gcp-ilb: only check if log_cmd binary is available if log_enable is true
  * rabbitmq-server-ha: use "s"-suffix for timeouts/intervals
  * rabbitmq-server-ha: rename and add to Makefiles
  * nvmet-subsystem: fix allowed_initiators for to avoid only running once (found by shellcheck)
  * gcp-ilb/Squid: fix issues detected by CI
  * configure: only run ci/build.sh when shellcheck is present
  * RabbitMQ OCF RA M/S HA cluster agent migration (#1698)
  * build: update ChangeLog for 4.10.0
  * build: update ChangeLog for 4.10.0-rc1
* Mon Oct 25 2021 varkoly@suse.com
- Update to version 4.9.0+git25.278c776d:
  * portblock: use ss when available, netstat is "obsolete"
  * iSCSILogicalUnit: do not use lio_iblock with lio-t
  * VirtualDomain: Added the ability to unset utilization variables (#1703)
  * nfsserver: Fix NFSv4 lock failover: set NFS Server Scope (#1688)
  * metadata.rng: update to support resource agent version according to the OCF standard
  * ocf.py: add agent and OCF version parameters (both defaults to 1.0)
  * ra-dev-guide: update agent/OCF version info (#1699)
  * all agents: specify agent and OCF versions corrently in metadata
  * nfsnotify: fix rpcuser error when resource start on debian (#1696)
  * gcp-pd-move/gcp-vpc-move-route: dont fail failed resources instantly (caused by OCF_ERR_CONFIGURED)
  * symlink: fix symlink vs target realpath comparison (#1691)
* Wed Sep 22 2021 varkoly@suse.com
- Update to version 4.9.0+git10.8dc8b40b:
  * storage-mon: update metadata to suggest usage in combination with HealthSMART agent
  * configure: use new SYSTEMD_ parameters
  * tools: add nfsconvert for RHEL-based distros
  * [tools] fix build on opensuse 15.3
  * nfsnotify: fix default value for "notify_args"
* Mon Aug 23 2021 varkoly@suse.com
- Update to version 4.9.0+git0.55a4e2c9:
  * build: update ChangeLog for 4.9.0
  * Filesystem: force_unmount: remove "Default value" to avoid confusion on RHEL9+ where default value is safe
  * build: update ChangeLog for 4.9.0-rc1
  * MySQL: add Support for local SSL connection (#1682)
  * SAPInstance: Fix for issue #1680 - SAPInstance fails to detect systemd integration (#1681)
  * [build] fix out-of-tree build for man pages
  * Filesystem: do not call partprobe for bind mounts
  * VirtualDomain: drop prefix xenmigr from migrate uri
  * iSCSILogicalUnit: lio-t: support setting product_id
  * storage-mon: new resource agent (#1675)
  * nvme-*: spelling fixes in meta data text
  * spec: remove chkconfig dependency for Fedora < 34
  * Remove a bashism in ocf-shellfuncs.in
  * NVMe-oF-Target: New RAs nvmet-subsystem nvmet-namespace nvmet-port
  * gcp-ilb: add to Makefiles
  * mdraid: add option description for OCF_CHECK_LEVEL
  * CTDB: replace timeout override with ctdb_timeout parameter (#1661)
  * findif: popen requires pclose and not fclose (#1664)
  * SAPInstance: add systemd compatability (#1662)
    (bsc#1189535) SAPInstance fails to detect SAP unit files for systemd
  * lvmlockd: remove cmirrord support as it's incompatible with lvmlockd
* Thu Jun 24 2021 varkoly@suse.com
- Update to version 4.8.0+git38.c6c53268:
  * podman: workaround race during container creation
  * VirtualDomain: Added code to set the host_memory value for Utilization (#1649)
  * gcp-vpc-move-vip: add serviceaccount JSON file support
  * gcp-vpc-move-route: add serviceaccount JSON file support
  * LVM-activate: fix drop-in check to avoid re-creating drop-in file when it already exists
  * Low: dummy: Add missing action to dummy_usage function
* Mon May 10 2021 varkoly@suse.com
- Update to version 4.8.0+git28.5c54175d:
  * LVM-activate: Disable VG autoactivation in system_id access_mode
  * gcp-vpc-move-vip.in: Adds retries
  * gcp-ilb: resource wrapping nc or socat to respond to health checks (#1541)
  * azure-events: update api_version
  * openstack-cinder-volume: CLI output parsing fixes, fetch of node ID consistency, monitor action simplification, and proper use of osvol_validate.
  * openstack-virtual-ip: New resource agent for virtual IP support in OpenStack.
  * openstack-floating-ip: Proper use of osflip_validate and small log message fixes.
  * configure: add /usr/local/share to fallback path to be scanned for docbook path
  * openstack-info: Use OSInfo_validate in start action. (#1639)
  (bsc#1178680) HA-LVM systemid race condition introduces an error "active on 2 nodes"
* Thu Apr 15 2021 varkoly@suse.com
- Update to version 4.8.0+git12.3068bf8b:
  * openstack-info: python variable substitution and test for json
  * VirtualDomain: ensure needed virtual storage pools and networks are up and refreshed
  * db2: add PRIMARY/REMOTE_CATCHUP_PENDING/CONNECTED status to promote-check
  * - Updates due to API output format changes. - Attempt to future-proof parsing of the output.
  * update aws-vpc-route53
  * build: add smb-share and fix & not passing XML check/manpage generation
  * smb-share: new RA to manage Samba shares on the fly. (#1628)
  * build: update ChangeLog for 4.8.0
  * podman: return OCF_NOT_RUNNING when monitor cmd fails (not running)
  * bundle: run crm_mon without performing validation
  * awsvip: dont partially match similar IPs during monitor-action
  * AWS agents: dont spam log files when getting token
  * build: update ChangeLog for 4.8.0-rc1
  * build: update ChangeLog for 4.7.0
  * ci/build.sh: skip Python agents and *.in
  * CI: run shellcheck tests during "make check" to move from Travis CI
  * Filesystem: fix force_unmount default to safe for RHEL9+ issue introduced in b792a143fc90468f8911243a5ea77c0c424bd624
  * azure-lb: Redirect stdout and stderr to /dev/null
  * azure-lb: Be quiet during stop operation
  * configure: dont use OCF_ROOT_DIR from glue.h
  * docker-compose: Bugfix handle ymls correctly
  * Filesystem: change force_unmount default to safe for RHEL9+
  * gcp-vpc-move-route: make "vpc_network" optional
  * VirtualDomain: fix pid_status() on EL8 (#1614)
  * spec: add BuildRequires for google lib
  * nfsserver: Error-check unbind_tree
  * gcp-vpc-move-vip: correctly return error when no instances are returned
  * gcp-vpc-move-route: fix stop-action when route stopped, and fix check_conflicting_routes()
  * The anything RA getpid() function can fail to return the pid in the OCF_RESKEY_pidfile if the root user has commands in .profile which prints numeric characters. To demonstrate, /root/.profile contains: echo -e '911 WARNING: YOU ARE SUPERUSER!' Write only the pid into the pidfile.
  * added real servers threshold settings to ldirectord
  * gcp-vpc-move-route, gcp-vpc-move-vip: Parameterize project ID
  * nfsclient: fix stop-action when export not present
  * heartbeat/Route: Return OCF_NOT_RUNNING status if iface doesn't exist.
  * pgsql: make wal receiver check compatible with PostgreSQL >= 11
  * Low: mysql-common: check datadir permissions
  * ocf-shellfuncs: make ocf_is_bash4() detect Bash v4 or greater (which it was supposed to according to the comments)
  * Dev: ocft: fix OCF_RESKEY_CRM_meta_timeout
  * build: update ChangeLog for 4.7.0-rc1
  * crypt: avoid failing for LVM exclusive by not running full sanity check during probes
  * LVM-activate: Fix return value in lvm_status()
  * LVM-activate: Remove local variables (bashisms)
  * LVM-activate: Stop before blk-availability.service
  * ocf-distro: Use Solaris-compatible grep
  * ocf-distro: Update version format
  * ocf-distro: Improve robustness and specificity (#1558)
  * [build] export ocfrootdir consistently
  * crypt: allow encrypted_dev to be symlink to support using devices in /dev/disk/... or UUID
  * heartbeat/iface-vlan: vlan_{interface,id} do not have to be unique.
  * [build] fix systemd paths when using non standard prefix
  * crypt: make key_file and crypt_type parameters not unique
  * Asterisk dir fix (#1583)
  * fix problem with unset OCF_RESKEY_CRM_meta_interval by cluster framework
  * AWS agents: add support for IMDSv2
  * Add pkg-config file
  * configure: add PKG_CHECK_VAR.m4 to avoid failing on older distros
  * configure: use pkg-config to detect systemd-paths to make CI able to define them the same way for all CL-projects
  * isRunning_cmd fix due to improper pkill parameters
  * configure: default to build heartbeat agents only
  * podman: recover from podman's storage being out of sync
  * podman: recover from killed conmon side process
  * aws-vpc-move-ip: Don't warn for expected scenarios
  * sybaseASE: add logfile parameter
  * galera: recover after network split in a 2-node cluster
  * man: use OCF_CHECK_LEVEL for depth parameters in pcs examples
  * crypt: fix missing && to set exit_reason
  * galera: set bootstrap attribute before promote
  * galera: fix check user configuration with clustercheck
  * ethmonitor: is_interface: RE matches vlan names
  * man: use promotable keyword in manpage examples
  * SAPInstance - introduce MINIMAL_PROBE resource parameter (#1564)
  * send_arp (libnet): use sigaction() instead of deprecated siginterrupt()
  * fixes and improvements
  * galera: recover from joining a non existing cluster
  * Filesystem: Default fast_stop to no for RHEL 9+ and for other distros
  * Fix ocf.py usage for py2 when self param is involved
  * galera: Fix automatic recovery when a cluster was not gracefully stopped
  * aws-vpc-move-ip: Fix the region option
  * aws-vpc-move-ip: Implemented optional eni lookup instead of the default instance id.
  * aws-vpc-move-ip: Add --region attribute
  * build: fix distcheck issue introduced by including READMEs in heartbeat directory
  * build: include all READMEs in heartbeat directory
  * spec: Recommends not supported for RHEL/CentOS 7 or older
  * - spec: ldirectord: added perl-IO-Socket-INET6 dependency on Fedora - spec: fix last remnants of 0%%{?centos_version}
  * gcp-vpc-move-vip: Fix sort for list of dicts in python3
  * filesystem: mmap search not specific enough
  * galera/redis: support RHEL 8.1 pacemaker
  * galera/redis: use --output-as for crm_mon w/newer Pacemaker, and prepare for Promoted role
  * azure-events: report error if jsondata not received
  * azure-events: import URLError and encode postData when necessary
  * nfsnotify: fix SELinux issue due to newer ls versions giving additional output.
  * nfsserver: fix SELinux issue due to newer ls versions giving additional output.
  * - spec: make Samba/CIFS dependency weak for Fedora 32 and RHEL/CentOS 8 and   remove the dependency for later Fedora/RHEL/CentOS versions
  * nfsserver: stop nfsdcld if present during stop-action
  * Enable comparing versions containing git hashes and more
  * azure-events: only decode() when exec() output not of type str
  * pgsql: support RHEL 8.1 pacemaker
  * Filesystem: Convert leading space characters to tabs
  * Filesystem: POSIX-compliant syntax for portability
  * Filesystem: Support whitespace in device or directory name
  * sybaseASE: Run verify_all() for start operation only
  * iSCSILogicalUnit: lio-t: Add pscsi LIO-T backing store
  * spec: fix lsb_release dependency
  * azure-lb: Don't redirect nc listener output to pidfile
  * send_ua/IPv6addr: use sigaction() instead of deprecated siginterrupt()
  * Fix typos in galera RA
  * [gcp-vpc-move-vip] Add support for multiple alias IP ranges on one node
  * [gcp-vpc-move-vip] Improve accuracy of metadata and log messages
  * docker-compose: bugfix (#1523)
  * Add support for LIO-T incoming CHAP auth for TPG
  (bsc#1183971) L3: azure-events puts both nodes in standby
  (bsc#1177796) ethmonitor bloats journal with warnings for VLAN
  (bsc#1180590) azure-events URLError fixed upstream
  (bsc#1184607) gcp-vpc-move-route resource agent file_cache is unavailable when using oauth2client
  (bsc#1179977) L3: anything RA stop operation fails if /root/.profile has unexpected content
  (bsc#1178977) ocf.py does not handle probe actions
  (bsc#1175435) Last commit of a galera cluster member is not saved into grastate.dat
  (bsc#1175101) GCP Resource Agents - Support for Multi Alias IP
  (bsc#1170354) OCF version check for pacemaker is incompatible with the SUSE version strings
* Mon Jun 22 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Fixes for %%_libexecdir changing to /usr/libexec
  * Changed all references of %%{_libexecdir} to {_prefix}/lib
* Fri Jun 19 2020 dakechi@suse.com
- Update to version 4.6.1+git2.b2dcccf1:
  * mdraid: fix bashism
  * build: update ChangeLog for 4.6.1
  * dummypy: make Python 2 compatible
  * dummypy: build fixes to generate the agent from the .in and generate manpage
  * build: update ChangeLog for 4.6.0
  * pgsql: use XML output for better backward and forward compatibility, and "Promoted" keyword to be ready for Pacemaker 2.1
  * build: fix failing to link if link already exists
  * ocf_is_ms(): also check OCF_RESKEY_CRM_meta_promotable to make it work w/Pacemaker 2.x
  * ldirectord: add support for ldaps
  * exportfs: fix ocft script failure
  * exportfs: fix bashism
  * aws-vpc-move-ip: fix bashism
  * aliyun-vpc-move-ip: fix bashism
  * podman: fix bashism
  * docker-compose: fix bashism
  * mdraid: fix bashism
  * crypt: fix bashism
  * Filesystem: set "fast_stop" default to "no" for GFS2 filesystems as they are likely to use more than 6 seconds to stop
  * build: update ChangeLog for 4.6.0-rc1
  * Fix _default variables in clvm RA.
  * exportfs: fix monitor-action in symlink-logic for when directory doesnt exist
  * nfsserver: prevent error messages when /etc/sysconfig/nfs does not exist
  * aliyun-vpc-move-ip: Add error log output (#1504)
  * High: docker-compose: new resource agent (#1499)
  * podman: make sure to remove containers with lingering exec sessions
  * tomcat: only create directory during start action
  * gcp-pd-move: fixes and improvements
  * nfsserver: fix NFSv4-only support
  * Medium: Squid: made squid_opts parameter available.
  * azure-events: handle exceptions in urlopen (#1496)
  * db2: HADR add STANDBY/REMOTE_CATCHUP_PENDING/DISCONNECTED to correctly promote standby node when master node disappears (e.g. via fencing)
  * Increase the rabbitmqctl wait timeout during start()
  * exportfs: add symlink support
  * Dummy RA in Python (#1490)
  * Eliminated logging.basicConfig() That method installed a root logger to be used with logging methods. The root logger is a stream logger which sends output to stderr, so every log data ended up in stderr as well
  * pgsql: support to crm_mon output for Pacemaker-2.0.3.
  * Replace aws command line with OCF_RESKEY_awscli property. (#1483)
  * mdraid: new resource agent
  * crypt: new resource agent (#1477)
  * Disable google api cache discovery
  * Importforce should not be a unique parameter.
  * Mid: postfix: Fixed ocf_exit_reason calling mistake.
  * Mid: dovecot: Fixed ocf_exit_reason calling mistake.
  * aws-vpc-move-ip: delete remaining route entries
  * Increase the security of monitor user in oracle
  * aws-vpc-route53: add support for public and secondary private IPs
  * aws-vpc-route53: cleanup and improvements
  * galera: Fix value used for connecting with the empty password.
  * ocf-shellfuncs: ocf_is_clone: update comment based on clone-max fix in previous commit
  * Fix audit issue with secure tmp file (#1468)
  * ocf-shellfuncs: fix ocf_is_clone() (clone_max can be 0 with cloned resources)
  * Make secure tmp files (#1467)
  * redis: run validate-action during start
* Mon Mar 23 2020 dakechi@suse.com
- Update to version 4.5.0+git2.32821fe4:
  * Filesystem: Add lustre as networked filesystem
  * build: update ChangeLog for 4.5.0
  * aws-vpc-move-ip: add routing_table_role parameter to metadata
  * iSCSILogicalUnit: fix default value for OCF_RESKEY_liot_bstype
  * build: update ChangeLog for 4.5.0-rc1
  * lvmlockd: remove locking_type parameter from lvm.conf for LVM > v2.03
  * Allow user to specify role with which to query/update route table
* Wed Feb 26 2020 Peter Varkoly <varkoly@suse.com>
- Request to add "gcp-vpc-move-route" resource agent to SLE12 and SLE15
  (bsc#1161898) Add patch:
  0007-Request-to-add-gcp-vpc-move-route.patch
* Wed Feb 26 2020 varkoly@suse.com
- Update to version 4.4.0+git57.70549516:
  * [lvmlockd] support lvm2-2.03 removing lvmetad
  * oralsnr: allow using the tns_admin directory for different listeners
  * Change 'alredy' to 'already'
  * LVM-activate: add OCF_CHECK_LEVEL to control monitor action
  * redis: validate_all: fixes file status tests
  * rabbitmq-cluster: ensure we delete nodename if stop action fails
  * IPsrcaddr: remove hardcoded device when using destination parameter
  * Remove standby.signal when promote with restart
  * IPsrcaddr: fixes to avoid failing during probe
  * LVM-activate: verify vg or lv validity
  * [podman] Simplify the code for checking if an image exists
  * Filesystem: add trigger_udev_rules_if_need() for -U, -L, or /dev/xxx device
  * Filesystem: respect udevd need time to create UUID symlinks
  * ldirectord: Support sched-flags
  * IPaddr2: ipt_CLUSTERIP "iptables" extension not "nft" backend compatible
  * IPsrcaddr: fixes to replace local rule if using local table, and set src back to primary for device on stop
  * iSCSI logical unit fix (#1435)
  * Clear out the $DIR_EXECUTABLE variable so we catch the situation when we lose the directory with binaries after first sapinstance_init invokation. The second sapinstance_init invocation will not detect it as it will have already preset the $DIR_EXECUTABLE from previous run. This may allow us running actions after second sapinstance_init invocation that would be not run if we knew that we miss the needed binaries.
  * High: pgsql: Support for PostgreSQL 12
  * IPaddr2: add noprefixroute parameter
  * Filesystem: refresh UUID in the start phase
  * azure-lb Set socat to default on SUSE distributions.
  * exportfs: allow multiple exports of same directory
  * Low: MailTo: fix variable expansion
  * iSCSILogicalUnit.in fixes (#1427)
  * Low: exportfs: Fix spelling error
  * Low: mysql-common: fix startup check
  * aliyun-vpc-move-ip: add binary detection
  * Supports both 'go' and 'python' versions of Aliyun CLI
  * build: update ChangeLog for 4.4.0
  * Low: NodeUtilization: Fix checking for Xen commands
  * build: update ChangeLog for 4.4.0-rc1
  * Route: only validate for start and validate-all actions
  * apache: testing to-execute-file for mere presence is not enough
  * LVM-activate: add partial-activation support
  * Add missed requirement
  * Use the function get_release_id to detect the OS. The parameter LOAD_STATUS_MODULE must be quoted.
  * gcp-pd-move: add parameter stackdriver_logging (#1412)
  * aws-vpc-route53: Improvements and fixes (#1409)
  * LVM-activate: move pvscan --cache to validate
* Mon Sep 30 2019 dakechi@suse.com
- Update to version 4.3.0+git178.b102c209:
  * Adapt azure-lb Resource Agent to support socat usage too (bsc#1150046)
  * redis: consider redis-cli features to choose optimal password passing method and warning filtering workaround (#1403)
  * fix master_is_active() erroneously reporting there is master when there is no fixes #1399
  * nfsserver: use "--no-legend" for systemctl "list-unit-files" calls
  * nfsserver: performance improvements for systemd enabled systems
  * IPaddr2: IPv6 return empty string when sanitation fails
  * Low: IPaddr2: fix to work properly with unsanitized IPv6 addresses
  * Filesystem: improve "/" check for bind mounts
  * IPsrcaddr: add destination and table parameters
* Mon Sep  9 2019 varkoly@suse.com
- Update to version 4.3.0+git161.00cb192d:
  * apache: correctly detect mod_status.so when statusurl is set
    (bsc#1138281)
  * Restore users/perms/policies even if starting in a single node mode
  * spec: use %%{?centos} as _version doesnt work on newer CentOS versions
  * exportfs: doc clarification for clientspec format
  * Fixup docker_stop condition on error
  * Make the check for the docker daemon being up more robust
  * Low: oracle-common: Delete the ORACLE_HOME check that is no longer needed because it is checked first.
  * Low: ora-common: Properly output message when sid parameter is invalid.
  * spec: updates from Fedora
  * spec: update to BR to libnet-devel for opensuse
  * CI: "make rpm" fixes
  * Route: dont fence node when parameters arent set
  * requested changes applied.
  * Added support for SSL replication
  * [build] drop now unnecessary make distcheck options
  * [build] allow systemd files to be installed in non-standard location
  * [build] fix make distcheck by adding fallback OS dir to find docbook.xsl
  * Don't call readlink on path if it does not exist
* Wed Aug 14 2019 dakechi@suse.com
- Update to version 4.3.0+git131.7af8c368:
  * mysql/mariadb/galera: use runuser/su to avoid using SELinux DAC_OVERRIDE
  * Generate addition drop-in dependencies for podman containers
  * Delay: protect grep regex argument from shell globbing
  * ipsec: fix bashism; [ a == b ] -> [ a = b ]
  * changing bashism to generic solution
  * iSCSILogicalUnit: only create acls if it doesnt exist
  * LVM-activate: fix monitor might hang due to lvm_validate which was added by accident
  * check if mod_status is present in configuration
  * Load apache status modules from RA cmdline for SUSE only OS (bsc#1138281)
  * Improve PidFile pattern
  * CTDB: drop sysconfig presence check during validate
  * CTDB: generate script.options file for 4.9+
  * podman: only use exec to manage container's lifecycle
  * Fix path to example for ocf python agent
  * CTDB: support Samba 4.9+ (bsc#1137130)
  * Medium: Filesystem: Prevents to all root user processes are killed when bind mounting a directory on rootfs.
  * aws-vpc-route53: Removed absolute path for awk command (bsc#1140874)
  * aws-vpc-route53: Tuning on dig timeout on r53_monitor function (bsc#1140874)
  * aws-vpc-route53: Change check interval in _update record function (bsc#1140874)
  * aws-vpc-route53: Remove unecessary tabs (bsc#1140874)
  * aws-vpc-route53: Normalize variable declaration (bsc#1140874)
  * aws-vpc-route53: Changed log line wording on r53_stop function (bsc#1140874)
  * aws-vpc-route53: Add --cli-connect-timeout 10 option to AWS CLI (bsc#1140874)
  * aws-vpc-route53: Add extra log line to r53_start function (bsc#1140874)
  * aws-vpc-route53: Replace ec2metada with curl to fetch the IP address directly from EC2 metadata (bsc#1140874)
  * aws-vpc-route53: Changes and improvements to r53_start function (bsc#1140874)
  * aws-vpc-route53: Changes and improvements to r53_stop function (bsc#1140874)
  * aws-vpc-route53: Changes and improvements to _update_record function (bsc#1140874)
  * aws-vpc-route53: Changes and improvements to r53_monitor function (bsc#1140874)
  * aws-vpc-route53: Add binary check for curl and dig (bsc#1140874)
  * aws-vpc-route53: Change in function names from ec2ip_* to r53_* (bsc#1140874)
  * aws-vpc-route53.in: Add missing quotes in ec2ip_stop() (bsc#1140874)
  * Filesystem: remove removed notify-action from metadata
  * Use _default variables in ZFS RA.
  * Use _default variables in Xinetd RA.
  * Use _default variables in Xen RA.
  * Use _default variables in WinPopup RA.
  * Use _default variables in vsftpd RA.
  * Use _default variables in VirtualDomain RA.
  * Use _default variables in VIPArip RA.
  * Use _default variables in varnish RA.
  * Use _default variables in tomcat RA.
  * Use _default variables in syslog-ng RA.
  * Use _default variables in SysInfo RA.
  * Use _default variables in Stateful RA.
  * Use _default variables in Squid RA.
  * Use _default variables in SphinxSearchDaemon RA.
  * Use _default variables in slapd RA.
  * Use _default variables in sg_persist RA.
  * Use _default variables in sfex RA.
  * Use _default variables in ServeRAID RA.
  * Use _default variables in SendArp RA.
  * Use _default variables in scsi2reservation RA.
  * Use _default variables in SAPInstance RA.
  * Use _default variables in SAPDatabase RA.
  * Use _default variables in rsyslog RA.
  * Use _default variables in rsyncd RA.
  * Use _default variables in Route RA.
  * Use _default variables in redis RA.
  * Use _default variables in Raid1 RA.
  * Use _default variables in rabbitmq-cluster RA.
  * Use _default variables in Pure-FTPd RA.
  * Use _default variables in proftpd RA.
  * Use _default variables in pound RA.
  * Use _default variables in postfix RA.
  * Use _default variables in portblock RA.
  * Use _default variables in podman RA.
  * Use _default variables in pingd RA.
  * Use _default variables in pgsql RA.
  * Use _default variables in ovsmonitor RA.
  * Use _default variables in oralsnr RA.
  * Use _default variables in oracle RA.
  * Use _default variables in oraasm RA.
  * Use _default variables in openstack-info RA.
  * Use _default variables in NodeUtilization RA.
  * Use _default variables in nginx RA.
  * Use _default variables in nfsnotify RA.
  * Use _default variables in mysql-proxy RA.
  * Use _default variables in ManageVE RA.
  * Use _default variables in ManageRAID RA.
  * Use _default variables in MailTo RA.
  * Use _default variables in machine-info RA.
  * Use _default variables in lxd-info RA.
  * Use _default variables in lxc RA.
  * Use _default variables in lvmlockd RA.
  * Use _default variables in LVM-activate RA.
  * Use _default variables in LVM RA.
  * Use _default variables in LinuxSCSI RA.
  * Use _default variables in jira RA.
  * Use _default variables in jboss RA.
  * Use _default variables in iSCSITarget RA.
  * Use _default variables in iSCSILogicalUnit RA.
  * Use _default variables in IPsrcaddr RA.
  * Use _default variables in ipsec RA.
  * Use _default variables in IPaddr2 RA.
  * Use _default variables in IPaddr RA.
  * Use _default variables in iface-vlan RA.
  * Use _default variables in ids RA.
  * Use _default variables in ICP RA.
  * Use _default variables in garbd RA.
  * Use _default variables in galera RA.
  * Use _default variables in fio RA.
  * Use _default variables in Filesystem RA.
  * Use _default variables in EvmsSCC RA.
  * Use _default variables in Evmsd RA.
  * Use _default variables in ethmonitor RA.
  * Use _default variables in eDir88 RA.
  * Use _default variables in Dummy RA.
  * Use _default variables in docker RA.
  * Use _default variables in dnsupdate RA.
  * Use _default variables in Delay RA.
  * Use _default variables in db2 RA.
  * Use _default variables in CTDB RA.
  * Use _default variables in clvm RA.
  * Use _default variables in ClusterMon RA.
  * Use _default variables in aws-vpc-move-ip RA.
  * Use _default variables in apache RA.
  * Use _default variables in aliyun-vpc-move-ip RA.
- Remove 0007-CTDB-support-Samba-4.9.patch
  * This patch was merged upstream.
* Fri Jun 14 2019 David Disseldorp <ddiss@suse.com>
- Fix CTDB resource agent for Samba 4.9.0 and later (bsc#1137130)
  * 0007-CTDB-support-Samba-4.9.patch
* Fri Jun 14 2019 dakechi@suse.com
- Update to version 4.2.0+git157.40de8382:
  * azure-events: change message log level for the non action messages (bsc#1137038, bsc#1137231)
  * Remove unneeded podman exec --help call
  * Simplify podman_monitor()
  * Avoid double call to podman inspect in podman_simple_status()
  * dhcpd: keep SELinux context
  * vsftpd: fix missing $ on exit code detected by CI
  * ocf_is_true: add True to regexp
  * Low: Filesystem: Fix missing mount point due to corrupted mount list
  * Low: Filesystem: Fix a problem umount is not executed in the event of a disk failure
  * pgsql: enhance checks in pgsql_real_start to prevent incorrect status gets
  * Set fdisk command options on Linux or BSD
  * Adds a virtio- prefix to check disk's availability
  * Use fdisk to physically check disks' availability
  * Monitor: check cinder volume locally without using the API
  * Bad variable name to export (sh syntax)
  * Use strict sh features (no bash regex)
  * Cinder: Manages a local cache and calls the API to get openstack_id
  * Medium: pgsql: Set initial score for primary and hot standby in the probe.
  * Volume re-attaching, v3 API, get hostname from corosync
* Tue Jun  4 2019 dakechi@suse.com
- Update to version 4.2.0+git122.571ed619:
  * Fix implicit bytes conversion that breaks py3. Reduces the amount of errors messages using default value on crm_attribute (bsc#1137038, bsc#1137231)
  * galera: Allow empty password for "check_passwd" parameter
  * Squid: dont run pgrep -P without PID
* Wed May 22 2019 tbechtold@suse.com
- Update to version 4.2.0+git116.b6c0f9fb:
  * galera: Log message when changing content of grastate.dat file
  * Use _default variables for all OCF_RESKEYs.
  * Use _default variable for binary path.
  * Drop unused LSB_STATUS_STOPPED variable.
  * Add resource agent for dovecot.
  * Fixes parameter meta-data
  * Fails docker RA gracefully when command not found Fails gracefully when daemon not running
  * CTDB: fix version string with vendor trailer comparison (bsc#1133337)
* Fri May  3 2019 dakechi@suse.com
- Update to version 4.2.0+git104.25f2052b:
  * Low: LVM: Change of return code when start fails.
  * galera: Ignore safe_to_bootstrap in grastate.dat in some cases
  * aws-vpc-move-ip: Linting adjustment (bsc#1133962)
  * aws-vpc-move-ip: Moving shared part outside if (bsc#1133962)
  * aws-vpc-move-ip: More robust approach of getting MAC address (bsc#1133962)
  * ethmonitor: fix is_interface() regression
  * aws-vpc-move-ip: Requested fix to avoid using AWS API (bsc#1133962)
  * aws-vpc-move-ip: Fixing indentation (bsc#1133962)
  * aws-vpc-move-ip: Fix for VM having multiple network interfaces (bsc#1133962)
  * add network namespace support to IPaddr2
  * [rabbitmq] Stop redirecting all output to /dev/null in set_policy
  * Support build and install on RHEL 6 (#1308)
  * gcp-vpc-move-route/gcp-vpc-move-vip: fix Python 3 encoding issue
  * IPsrcaddr: make proto optional to fix regression when used without NetworkManager
  * LVM-activate: align dmsetup report command to standard
  * LVM-activate: return OCF_NOT_RUNNING on initial probe (bsc#1114855)
  * ethmonitor: check if interface exists by link
  * Squid: fix pid file issue due to new Squid version saving the PID of the parent process instead of the listener child process
  * Restrict strncpy by size of target, not of source. Fixes gcc error/warning
  * CTDB: add ctdb_max_open_files parameter
  * LVM-activate: only check locking_type when LVM < v2.03
  * redis: Filter warning from stderr when calling 'redis-cli -a'
  * LVM-activate: fix indentation
- Remove 0007-LVM-activate-return-OCF_NOT_RUNNING-on-initial-probe.patch
  * This patch was integrated upstream and is not needed as an extra patch.
* Tue Apr  2 2019 ghe@suse.com
- LVM-activate returns the correct value on initial probe (bsc#1114855)
  * 0007-LVM-activate-return-OCF_NOT_RUNNING-on-initial-probe.patch
* Mon Feb 18 2019 dakechi@suse.com
- Update to version 4.2.0+git63.0f7987fb:
  * clvm: support exclusive mode
  * Revert " Added support for multiple slaves to pgsql."
  * azure-lb: remove reference to status from usage
  * configure: add Python library detection
  * Added support for multiple slaves to pgsql.
  * LVM-activate: make vgname not uniqe
  * LVM-activate: fix dmsetup check
  * LVM-activate: fix bashism [[
  * Route: make family parameter optional
  * LVM-activate: dont fail initial probe
  * docker: Fix issues with stop operation
  * rabbitmq-cluster: always use quiet flag for eval calls
  * aws-vpc-move-ip: multiple VPC routing tables in routing_tables parameter - included comment in metadata section (bsc#1125138)
  * aws-vpc-move-ip: multiple VPC routing tables in routing_tables parameter - adjusting sleep time (bsc#1125138)
  * aws-vpc-move-ip: new feature: include support for multiple routing tables (bsc#1125138)
* Thu Dec  6 2018 kgronlund@suse.com
- Update to version 4.2.0+git33.69a622fd:
  * rabbitmq-cluster: better ensure node attributes are removed
  * Do not log at debug log level when HA_debug is unset
  * Enable --query flag in DescribeRouteTable API  (#1269)
  * Moved more Code to the Legacy section and cleaned the Legacy code as we already know that we are on pre-1.0 Version
  * Add lxc-stop Timeout
  * Remove Parameter and replace with Version Check
  * lxc: Add Support for lxc-stop
  * rabbitmq-cluster: fix regression in rmq_stop
  * rabbitmq-cluster: debug log detailed output when mnesia query fails
  * SAPDatabase: Improved the documentation about HANA usage
- Remove 0001-Revert-Add-additional-info-to-SAPDatabase-RA.patch
* Thu Nov  1 2018 kgronlund@suse.com
- Update to version 4.2.0+git8.7c750bab:
  * heartbeat/{docker,podman,rkt}: nicer treatment of "reuse" parameter
  * Maint: fix several typos discovered with "make spellcheck"
  * Fix demote example log line.
* Mon Oct 22 2018 kgronlund@suse.com
- Included the missing azure-events RA needed for maintenance on the
  Azure Public Cloud. (bsc#1112334)
- Included the ocy.py library used by the azure-events RA (bsc#1112334)
- Update to version 4.1.1+git24.9b664917:
  * apache: fix return value for silent_status
  * ZFS: cleanup different indentations
  * Fix spelling error in gcp-vpc-move-ip/route
  * Initial version of the azure-events RA
  * rabbitmq-cluster: fail monitor when node is in minority partition
  * ZFS agent: check status without locks when possible
  * Mid: pgsql: Fix to ignore Master's re-promote.
  * Low: oracle: print more appropriate log when dbopen was failed
  * Low: oracle: accept any boolean value for clear_backupmode option
  * nfsserver: run prepare_directory after bind_tree and stop var-lib-nfs-rpc_pipefs.mount to fix issues when changing shared_infodir
  * CTDB: fix --logging/--logfile version string comparison (bsc#1102935)
  * Do not use the absolute path in redis' pidof calls
  * awseip: Documentation updates to prerequisites
  * nfsserver: only mount rpc_pipefs if it's not mounted
  * nfsserver: mount based on rpcpipefs_dir variable
  * LVM-activate: fixes
  * IPv6Addr/nagios/sybaseASE: add missing "s"-suffix in metadata
  * Add gcp-pd-move python script
  * Medium: Squid: Use ss if netstat is not available
  * Medium: portblock: Use ss or netstat (partial)
  * Medium: garbd: Use netstat or ss
  * Mid: apache: Retry pid check.
  * timeout/interval: add "s" suffix where it's missing
  * Low: Xen: Set utilization for cpu and hv_memory
  * pgsql: create replication slots after promoting master
  * VirtualDomain: add stateless support
- Add 0001-Revert-Add-additional-info-to-SAPDatabase-RA.patch
* Fri Sep  7 2018 dakechi@suse.com
- Created the symlink for the suse:aws-vpc-move-ip RA for backward
  compatibility reasons. The package aws-vpc-move-ip will be dropped
  and the Upstream resource agent will be the only one maintained.
  (fate#326697)
* Tue Sep  4 2018 abriel@suse.com
- Update to version 4.1.1+git165.1ddbf85d:
  * Add Python library
  * gcp-vpc-move-vip: use Python library
  * gcp-vpc-move-vip: moved alias-parameters to top of metadata
  * gcp-vpc-move-route: use Python library
  * Python: add logging.basicConfig() to support background logging
  * CTDB: fix incorrect db corruption reports (bsc#1101668)
  * CTDB: explicitly use bash shell
  * CTDB: fix OCF_RESKEY_ctdb_recovery_lock validation (bsc#1088692)
  * aws-vpc-move-ip: Use ip utility to check address
  * rabbitmq-cluster: retry start when cluster join fails
  * ipsec: Add tunnel fallback option
  * LVM: fix missing dash (bsc#1104900)
  * Remove output redirection to file in /tmp
  * Medium: mysql: Remove obsolete DEBUG_LOG functionality (bsc#1021689)
  * lvmlockd: add cmirrord support
  * Initial podman support
  * LVM-activate: return OCF_ERR_CONFIGURED for incorrect vg_access_mode
  * spec: fix some overkil path-based Requires, trailing whitespace, thinko
  * rabbitmq-cluster: get cluster status from mnesia during monitor
  * aws-vpc-move-ip: Fix broken shell quoting
  * Filesystem: Support symlink as mountpoint directory
  * aliyun-vpc-move-ip: improve metadata and manpage
  * aws-vpc-move-ip: Check the rounting table also during monitor probe action ((bsc#1106707)
  * aws-vpc-move-ip: Force text output during awscli call ((bsc#1106707)
  * aws-vpc-move-ip: Included the address param for backward compat. Evaluate if the address param is set and if the ip para is null, and set the ip param with the address value. ((bsc#1106707)
  * pgsql: Avoid the change of /dev/null to postgres owner/group The check_log_file performs a -f test on the logfile which is set to /dev/null by default, and it returns 1 for non-regular files. (bsc#1090882)
  * Filesystem: Canonicalize mountpoint symlinks
* Thu Aug  9 2018 dakechi@suse.com
- Update to version 4.1.1+git118.9a4fbd24:
  * SAPInstance: Improved SAP instance profile detection (bsc#1096744)
  * findif: only match lines containing netmasks
  * SAPInstance: Improved indents (bsc#1096744)
  * SAPInstance: implemeted reload method (bsc#1096744)
  * build: add missing manpages
  * aliyun-vpc-move-ip: fix manpage (fate#326557)
  * aliyun-vpc-move-ip: fixes. (fate#326557)
  * Add Aliyun vpc-move-ip agent. (fate#326557)
  * gcp-vpc-move-route.in: minor fixes
  * gcp-vpc-move-route.in: move stackdriver parameter
  * gcp-vpc-move-vip.in: filter call to aggregatedList
  * gcp-vpc-move-ip.in: add deprecation message
  * gcp-vpc-move-route.in: python implementation of gcp-vpc-move-ip.in
  * Do not call ocf_attribute_target in the meta-data function
  * sfex: fixes to avoid errors with latest gcc
  * gcp-vpc-move-vip.in: minor fixes
  * gcp-vcp-move-vip.in: implement validate-all
  * gcp-vpc-move-vip.in: minor fixes
  * gcp-vpc-move-vip.in: manage ip alias
  * CI: skip Python agents in shellcheck
  * configure: add Python path detection
  * Volume groups and logical volumes "-" in their name get mangled with double dashes in dmsetup.  Switching to wc and just counting lines while depending on the vgname + lvname filter in the dmsetup call gets around the issue with dmsetup outputting correctly but grep failing due to the name mangle.
  * Mid: IPaddr2: Change return code.
  * ra-dev-guide: update instructions for GitHub
  * sybaseASE: bash path-detection
  * sybaseASE: new resource agent
  * gcp-vpc-move-ip: check specificed gcloud binary in validate
* Wed Jun 27 2018 kgronlund@suse.com
- Unify source package with SLE 12 / Leap 42:
  * High: oracle: Fix alter user syntax for set_mon_user_profile (bsc#1089279)
  * Medium: Raid1: Ignore transient devices after stopping a device (bsc#1077416)
  * Low: Raid1: remove unnecessary wait flags (bsc#1077416)
  * Medium: aws-vpc-route53: Fix tempfile race (bsc#1059312)
  * High: aws-vpc-route53: Add agent for AWS Route 53 (fate#322781)
  * VirtualDomain: Properly migrate VMs on node shutdown (bsc#1074014)
  * Low: sg_persist: Read empty value when when no attribute exists (bsc#1048288)
  * High: aws-vpc-route53: Add agent for AWS Route 53 (fate#322781)
  * Medium: Raid1: Handle case when mddev is a symlink(bsc#1047991)
  * Low: ocf-shellfuncs: Avoid printing empty INFO messages (bsc#1053621)
  * Low: SAPInstance: Mention monitor support in documentation (bsc#1051913)
- Obsoletes the following patches (SLE 12 / Leap 42):
  * 0001-High-oracle-Fix-alter-user-syntax-for-set_mon_user_p.patch
  * 0005-Medium-CTDB-Use-logging-syntax-for-ctdbd-bsc-981863.patch
  * 0007-Low-sg_persist-Read-empty-value-when-when-no-attribu.patch
  * 0008-High-aws-vpc-route53-Add-agent-for-AWS-Route-53-fate.patch
  * 0009-Medium-Raid1-Handle-case-when-mddev-is-a-symlink.patch
  * 0010-High-CTDB-Don-t-fail-on-empty-directory-bsc-1052577.patch
  * 0011-Low-ocf-shellfuncs-Avoid-printing-empty-INFO-message.patch
  * 0012-Low-SAPInstance-Mention-monitor-support-in-documenta.patch
  * 0013-High-galera-Backport-galera-fixes-from-upstream-bsc-.patch
  * 0014-VirtualDomain-Properly-migrate-VMs-on-node-shutdown-.patch
  * 0015-Low-aws-vpc-route53-Fix-missing-ocf_log-in-log-messa.patch
  * 0016-High-aws-vpc-route53-Add-agent-for-AWS-Route-53-fate.patch
  * 0017-Low-aws-vpc-route53-Fix-missing-ocf_log-in-log-messa.patch
  * 0018-Medium-aws-vpc-route53-Fix-tempfile-race-bsc-1059312.patch
  * 0019-Dev-aws-vpc-route53-Eliminate-duplicated-code.patch
  * 0020-Dev-aws-vpc-route53-Clean-up-logging.patch
  * 0021-Low-Raid1-remove-unnecessary-wait-flags-bsc-1077416.patch
  * 0022-Medium-Raid1-Ignore-transient-devices-after-stopping.patch
* Wed Jun 20 2018 kgronlund@suse.com
- Update to version 4.1.1+git70.00ae6a17:
  * Medium: pgsql: Fix incorrect SQL is selected with PostgreSQL 11 or later.
  * log the error message in abnormal_end() function even when we are in 'stop' operation so it is clear from logs on how did we end up here
  * Medium: SAPInstance: Add monitored services for ENSA2 (bsc#1092384)
  * Squid: cleanup description for squid_port parameter
  * ldirectord: add manpage to service documentation
  * Medium: Add openstack resource agents
  * findif: improve IPv6 NIC detection
  * awseip: fix allocation_id not found error
  * awsvip: get secondary-private-ip more precisely
  * awsvip: get network-id from meta-data directly
  * syslog-ng: added note that qdisk_dir is only supported in PE6
  * syslog-ng: merge Premium Edition 6 and 7 code into main agent
  * send_arp: dont use "-Wcast-align" due to false-positive fail on ARM.
  * gcp-vpc-move-ip: fix bash path-detection
  * enable chap authentication for lio-t iscsi target implementation. if attribute 'incoming_username' is set: enable attribute 'authentication', disable attribute 'generate_node_acls' and set chap 'userid' and 'password' for each 'allowed_initiator'
  * Low: exportfs: Fix inconsistent whitespace in exportfs_monitor
  * Medium: exportfs: Fix square bracket stripping in clientspec
  * Low: VirtualDomain: fix warning messages in log
  * New RA that manage IP moving in GCP
* Mon Apr 16 2018 kgronlund@suse.com
- Require /usr/bin/logger (provided by util-linux-systemd)
* Tue Mar  6 2018 kgronlund@suse.com
- Update to version 4.1.1+git0.5a1edf2b:
  * High: mpathpersist: Fixed problem that character string could not be correctly parsed (bsc#1083896)
  * High: VirtualDomain: Properly migrate VMs on node shutdown (bsc#1074014)
  * Medium: awseip/awsvip: improvements (incl multi NIC support)
  * Medium: awseip/awsvip: increase default "api_delay" to 3s to avoid failures
  * Low: pgsql: try to create stats_temp_directory
  * Low: Filesystem: Add support for cvfs
  * Low: pgsql: improve validations for replication mode
* Wed Feb  7 2018 jengelh@inai.de
- Edits to description, and compact build commands.
* Wed Feb  7 2018 kgronlund@suse.com
- Update to version 4.1.0+git83.6c77ce7e:
  * Medium: Raid1: Ignore transient devices after stopping a device (bsc#1077416)
  * redis: add support for tunneling replication traffic
  * Low: ovsmonitor: Generate man page for ovsmonitor (fate#323276)
  * Low: Raid1: remove unnecessary wait flags (bsc#1077416)
  * Pacemaker 2.0 compatibility (fate#324508):
  * Low: Xen: Use "crm_attribute --name/-n" instead of deprecated "--attr-name"
  * Low: Xen,redis: Use "crm_attribute --query/-G" instead of deprecated "--get-value"
  * Low: db2,galera,NodeUtilization: Use "crm_attribute --quiet/-q" instead of deprecated "-Q"
  * Low: sfex_daemon: Use "crm_resource --node/-N" instead of deprecated "--host-uname/-H"
  * Low: Xen,NodeUtilization: Use "crm_attribute --node/-N" instead of deprecated "--node-uname/-U"
  * Low: vmware: Do not reference the dropped cluster property "default_action_timeout"
- Remove patch merged upstream:
  * 0001-Drop-python-from-build-system-since-nothing-uses-it.patch
* Wed Jan 17 2018 kgronlund@suse.com
- Drop python requirement (bsc#1076413)
  * 0001-Drop-python-from-build-system-since-nothing-uses-it.patch
* Wed Jan 17 2018 kgronlund@suse.com
- Use python3 (bsc#1076413)
* Fri Jan 12 2018 kgronlund@suse.com
- Update to version 4.1.0+git59.a0452207:
  * lvmlockd: auto change lvm config to use lvmlockd (fate#323822)
  * LVM-activate: put all validations into lvm_validate (fate#323822)
  * mariadb: GTID/semi-sync based MariaDB Master/Slave resource-agent
* Tue Jan  9 2018 kgronlund@suse.com
- Update to version 4.1.0+git54.b264e401:
  * mpathpersist: New agent (fate#324044)
  * jira: New resource agent
  * azure-lb: New resource agent
  * lxc-info/machine-info: New agents for monitoring containers/machines
  * Low: redis: Check read bit on redis config
  * Low: IPsrcaddr: Only check for ifconfig on BSD/solaris
  * Medium: CTDB: Cope with deprecated "idmap backend" smb.conf option
  * Medium: oracle: Fix alter user syntax for set_mon_user_profile
  * Medium: db2: improve monitor and simplify STANDBY/.../DISCONNECTED
  * Medium: CTDB: fix initial probe
  * Medium: ethmonitor: add intel omnipath support
  * Medium: LVM-activate: avoid unnecessary validation in stop action
  * Medium: IPsrcaddr: match exact route to avoid failing
* Thu Nov 23 2017 kgronlund@suse.com
- Update to version v4.1.0rc1~git8.2900c751:
  * Drop libnet dependency (bsc#1069596)
  * db2: fix HADR promote when master failed
  * Add resource agent for IPSEC tunnels
  * Mid: apache: Move the stop judgment last.
  * Mid: apache: Eliminate wasteful TERM transmission, correct the waiting time correctly.
  * galera: recover from empty gvwstate.dat
  * Revert "LVM: use vgscan --cache to update metadata during start/relocate"
  * Medium: IPaddr2: do not send Gratuitous ARPs in the Cluster IP configuration
  * Medium: IPaddr2: add send_arp_opts parameter
  * Medium: IPaddr2: allow to choose arping instead of send_arp binary
  * Low: send_arp.linux: print proper usage
  * Low: IPaddr2: document arp_interval as deprecated
  * Low: IPaddr2: remove metadata of an unused parameter arp_mac
  * Low: IPaddr2: always remove orphan pidfile
  * Low: IPaddr2: use ocf_log for an output from send_arp
* Fri Nov  3 2017 kgronlund@suse.com
- Update to version 4.0.1+git.1509705432.020b5b34:
  * LVM-activate: add new RA for LVM activation (fate#323822)
  * nfsserver: allow stop to timeout
  * adding docker-native healthcheck query to docker
* Wed Nov  1 2017 kgronlund@suse.com
- Update to version 4.0.1+git.1508859013.2b3cb4a6:
  * Medium: aws-vpc-route53: Fix tempfile race (bsc#1059312)
  * High: pgsql: Support PG10: Following the change of the PostgreSQL function name.
  * High: pgsql: Support PG10: Following the change of the default action of "pg_ctl start" and "pg_ctl promote".
* Mon Sep  4 2017 kgronlund@suse.com
- Update to version 4.0.1+git.1504527822.722ffb5b:
  * High: ovsmonitor: Add OpenvSwitch monitor agent (fate#323276)
* Thu Aug 31 2017 kgronlund@suse.com
- Update to version 4.0.1+git.1504207605.22ac330c: (bsc#1053207)
  * galera: Honor "safe_to_bootstrap" flag in grastate.dat (bsc#1055017)
  * galera: Fix instance name in master_exists() (bsc#1056635)
* Thu Aug 31 2017 kgronlund@suse.com
- Update to version 4.0.1+git.1504170332.70fbcd8a:
  * Medium: ocf-shellfuncs: improve locking (ocf_take_lock)
  * Low: ocf-shellfuncs: Avoid printing empty INFO messages (bsc#1053621)
  * Low: SAPInstance: Mention monitor support in documentation (bsc#1051913)
  * High: lvmlockd: add resource agent for lvmlockd daemon (fate#323822)
  * High: rkt: Add agent for managing rkt containers
  * Medium: varnish: Compatibility for version 4.0
* Mon Aug 28 2017 kgronlund@suse.com
- Update to version 4.0.1+git.1503904762.b4582bdb:
  * Low: mysql: Fixed bug where crm_admin is never called, leaving master scores to -1 in certain conditions.
  * Low: exportfs: check fsid parameter for not containing a comma
  * Low: mysql: don't run ocf_is_ms check in a subshell
  * Low: redis: add check for redis-check-rdb
  * Low: redis: wait for pid file to appear after start
  * High: pgsql: Allow dynamic membership
  * Medium: CTDB: fix issue with --logfile being replace with --logging
  * Medium: oraasm: new resource agent for Oracle ASM Disk Groups
  * Medium: rabbitmq-cluster: Backup and restore policies
  * Low: Raid1: Clean up spelling and whitespace
  * Medium: LVM: use vgscan --cache to update metadata during start/relocate
  * Medium: LVM: warn when cache mode is not writethrough
  * Medium: iSCSILogicalUnit: add emulate parameters
  * Medium: mysql: Properly Detect read_only State
  * Medium: anything: Allow multiple instances of binfiles to be run (pidfile will be unique)
  * Medium: anything: Start should return OCF_RUNNING if monitor succeeds
  * Medium: anything: Attempt to fix missing PID directory before starting
  * Medium: kamailio fixes and enhancements for v5.0
  * Low: portblock: dont log dd "0+0 records in/out"
  * Medium: Raid1: Handle case when mddev is a symlink
  * Low: sg_persist: Read empty value when when no attribute exists (bsc#1048288)
  * Medium: VirtualDomain: new attributes migrateuri, remoteuri, migration_user
  * Low: sapdb: Add hdbnameserver to monitor services
  * High: CTDB: Don't fail on empty directory (bsc#1052577)
  * High: minio: Resource agent for the minio storage server
  * High: ZFS: Add ZFS Resource Agent
  * High: awseip/awsvip: fixes and improvements
  * Medium: VirtualDomain: new configuration option shutdown_mode
  * Medium: Route: Resource key for the address family (ip4, ip6 or detect)
  * Low: aws-vpc-route53: Fix missing ocf_log in log message
- Remove patches merged upstream:
  * Remove 0005-Medium-CTDB-Use-logging-syntax-for-ctdbd-bsc-981863.patch
  * Remove 0008-Low-sg_persist-Read-empty-value-when-when-no-attribu.patch
  * Remove 0010-High-CTDB-Don-t-fail-on-empty-directory-bsc-1052577.patch
  * Remove 0009-High-aws-vpc-route53-Add-agent-for-AWS-Route-53-fate.patch
  * Remove 0007-Medium-Raid1-Handle-case-when-mddev-is-a-symlink.patch
* Mon Aug  7 2017 kgronlund@suse.com
- High: CTDB: Don't fail on empty directory (bsc#1052577)
  * Add 0010-High-CTDB-Don-t-fail-on-empty-directory-bsc-1052577.patch
* Sun Jul 16 2017 kgronlund@suse.com
- High: aws-vpc-route53: Add agent for AWS Route 53 (fate#322781)
  * Add 0009-High-aws-vpc-route53-Add-agent-for-AWS-Route-53-fate.patch
- Low: sg_persist: Read empty value when when no attribute exists (bsc#1048288)
  * Add 0008-Low-sg_persist-Read-empty-value-when-when-no-attribu.patch
* Fri Jul 14 2017 zlliu@suse.com
- Medium: Raid1: Handle case when mddev is a symlink(bsc#1047991)
  0007-Medium-Raid1-Handle-case-when-mddev-is-a-symlink.patch
* Wed May 17 2017 kgronlund@suse.com
- Update to version 4.0.1+git.1495055229.643177f1:
  * High: SAPInstance: Add IS_ERS parameter (bsc#1036486)
  * High: DB2: fix HADR support for DB2 V98+ (bsc#1035470)
  * Medium: iSCSILogicalUnit/iSCSITarget: protect targetcli invocations with locks
  * Medium: iSCSILogicalUnit: lio-t IPv6-support
  * Medium: LVM: add check_writethrough parameter
  * Medium: galera: fix permission of temporary log file for mariadb 10.1.21+
  * Medium: galera: fix the first bootstrap when cluster has no data
  * Medium: docker: fix to deal with the image name correctly.
  * Medium: named: Add support for rndc options in named resource agent.
  * Medium: NodeUtilization: Add NodeUtilization agent
  * Medium: rabbitmq-cluster: Allow the rabbitmq cluster to work on pacemaker remote nodes
  * Medium: galera: fix master target during promotion with cluster_host_map
  * Medium: IPaddr2: add option for specifying IPv6's preferred_lft
  * Medium: docker: Allow callers to specify a set of directories that should be created if the don't exist
  * Low: pgsql: fix regex in set async mode
  * Low: added kamctl parameter as it was missing, causing issues if kamctl is not in PATH
  * Low: clvm: remove reload action from metadata
  * Low: iSCSILogicalUnit: replace openssl call with md5sum
  * Low: nginx: fix return code for configfile err
  * Add 0006-Revert-ocf_log-use-same-log-format-as-pacemaker.patch
* Wed Feb  1 2017 kgronlund@suse.com
- Update to version 4.0.0+git.1485962683.3b5faae:
  * Also backup users permissions. Skip guest user permission for vhost /
  * Low: slapd: Change of the stop processing.
  * LVM: add error messages for partial_activation
  * Low: apache: Reduce log spam for success
  * Low: findif.sh: Correctly redirect output to /dev/null
  * Low: eDir88: Fix incorrect shell usage
  * Low: redis: Fix error in log output
  * Low: tomcat: Fix incorrect shell usage
  * Low: rabbitmq-cluster: Fix incorrect shell usage
  * Low: Filesystem: Fix incorrect shell usage
  * Low: nginx: Fix incorrect shell usage
  * Low: ServeRAID: Fix incorrect shell usage
  * Low: postfix: data_dir loop could only ever run once
  * Low: SysInfo: Convert test series to legal syntax
  * tomcat: fix systemd tomcat start script check
  * galera: make last commit parsing compatible with mariadb 10.1.18+
  * galera: prevent promote right after demote
  * ifcheck must not suppress stdout of "ip" command so that it can be printed out in case of an error (e.g., usage in findif_check_params).
  * Medium: IPaddr2: add option to enable sending refresh arp packets in monitor
  * Low: IPaddr2: Log refresh arp packets at debug level instead of info
  * pgsql: fix problem with creating replication slot names, when node count greather then 2
  * Low: Update outdated mailing list/wiki references
  * Enable dump/restore users from RabbitMQ ver. 3.6.x
  * Don't run scriptlets if Mnesia isn't available
  * Don't call erlang:halt/0 inside of the working node
  * Remove file only if successfully imported users
  * Dump users only if non-empty
  * Improve dump/restore ofusers' permissions
  * Restore users' permissions only if Mnesia is running
  * RabbitMQ: Reset Mnesia before joining existing cluster
  * portblock: Use -w (wait) to avoid "insufficient privileges" error
  * portblock: version check for -w
  * Double-quote value of synchronous_standby_names in rep_mode.conf
  * specfile: make requirements general and update comments
  * Filesystem: check if there are any mounts mounted under the mountpoint
  * IPaddr2: return success on stop with invalid IP
  * Fix typo in IPaddr2
  * Fix grammar and spelling in some resource agents
  * galera: allow names in wsrep_cluster_address to differ from pacemaker nodes' names
  * IPaddr2 detect duplicate IP
  * redis: use "CLIENT KILL type normal" to notify clients of master being demoted
  * specfile: Add metadata.rng to the file to be collected
  * Adds support for fstype=zfs on Filesystem resource agent
  * LVM: fix partial activation
  * galera: revert "long SST monitoring" PR #684 and #762
  * Medium: exportfs: Only strip brackets from edges of clientspec (bsc#1022223)
- Rebase patches:
  * Add 0001-LVM-Default-partial_activation-to-true-in-SLE-HAE.patch
  * Add 0002-nfsserver-fix-path-to-sm-notify.patch
  * Add 0003-ldirectord-don-t-create-subsys-lock.patch
  * Add 0004-Revert-Low-build-Move-binaries-in-usr-lib-heartbeat-.patch
  * Add 0005-Medium-CTDB-Use-logging-syntax-for-ctdbd-bsc-981863.patch
  * Remove lvm-vg-partial-active.diff
  * Remove resource-agents-nfsserver-sle11.patch
  * Remove no-var-lock-subsys.patch
  * Remove 0006-Revert-Low-build-Move-binaries-in-usr-lib-heartbeat-.patch
  * Remove 0001-Medium-CTDB-Use-logging-syntax-for-ctdbd-bsc-981863.patch
* Wed Nov  2 2016 kgronlund@suse.com
- Update to version 3.9.7+git.1478106349.5ff08d4:
  * tomcat: Add force_systemd parameter to rely on systemd service
  * nfsserver: dont stop rpcbind, as other services might use it
  * ldirectord: a further fix for spurious reminder e-mails
  * Medium: docker: Reduce monitor log spam
  * Medium: mysql-proxy: Fix incorrect conditional reported by shellcheck
  * Medium: garbd: Fix broken probe check
  * Doc: docker: Clarify limitations of monitor_cmd in parameter description
* Tue Nov  1 2016 kgronlund@suse.com
- Update to version 3.9.7+git.1477655995.de4be97:
  * adjusting sapdb.sh to work with HANA Multi-Tenant Databases (bsc#1007142)
  * Medium: docker: Use docker exec for monitor_cmd if supported (bsc#1007867)
  * sg_persist: fix matching of hex node ids
  * sg_persist: do not spill info output to stderr
  * lvm.sh: fix status clustered to check the specified logical volume
  * Delay: set default startdelay lower than start timeout to avoid it timing out before starting with default values
  * Low: Filesystem: Clearer exit reason if mount fails
* Tue Oct 18 2016 kgronlund@suse.com
- Update to version 3.9.7+git.1475827855.a95ea74:
  * High: nfsserver: Delete the temp file correctly.
  * Low: nfsserver: Prevent unnecessary log output
* Tue Oct 18 2016 kgronlund@suse.com
- Revert send_arp to libnet version (bsc#985486)
  * For infiniband support in IPaddr2, install ipoibtools
* Thu Oct  6 2016 kgronlund@suse.com
- Update to version 3.9.7+git.1475676827.4af1003:
  * High: rabbitmq-cluster: forget stopped rmq nodes with notify=true
  * [rabbitmq-cluster] Backup and restore rabbitmq users during resource restart
  * RabbitMQ: New error code - 69
  * RabbitMQ: Forget node before 2nd joining attempt
  * rabbitmq: Allow automatic cluster recovery before forcing it
  * oracle: fix MONPROFILE to use monprofile parameter when set
  * oracle: fix issue with C## in monprofile (bsc#1005424)
  * oracle: add quotes for monuser and monpassword
  * Medium: pgsql: change stop_escalate parameter as usable value
  * Low: pgsql: adjust stop_escalate time when it is longer than the timeout
  * [galera] Add /etc/default/clustercheck importation
  * Medium: ldirectord: Fix the issue in IPv4/IPv6 mixed environment
  * ldirectord: Do an initial check of all services in when in 'starting' status
  * Low NFS: add more default init scripts to check
  * exportfs: Add pseudo resource factor (bsc#978680)
  * exportfs: Add IPv6 support
  * Low: extend support for AWS elastic ip association
  * Low: Rename ra-dev-guide.txt to ra-dev-guide.asc
  * garbd: Introduces garbd resource-agent
- Drop merged patches:
  * Remove 0001-Medium-ldirectord-Remove-IPv6-workaround-bsc-977193.patch
  * Remove 0001-exportfs-Add-pseudo-resource-factor-bsc-978680.patch
* Thu Aug 11 2016 kgronlund@suse.com
- Use non-libnet version of send_arp for IB support (bsc#985486)
* Thu Jun 30 2016 tchvatal@suse.com
- Remove unused conditions from the spec-file as we build only on
  new enough distributions
- Sort all variables with spec-cleaner for better readability
- Enable monitoring subpkg as we now have all the needed dependencies
- Convert to pkgconfig style dependencies where applicable
* Tue Jun 28 2016 kgronlund@suse.com
- exportfs: Add pseudo resource factor (bsc#978680)
- Add 0001-exportfs-Add-pseudo-resource-factor-bsc-978680.patch
* Mon May 30 2016 kgronlund@suse.com
- Medium: ldirectord: Remove IPv6 workaround (bsc#977193)
- Medium: CTDB: Use --logging syntax for ctdbd (bsc#981863)
- Add 0001-Medium-ldirectord-Remove-IPv6-workaround-bsc-977193.patch
- Add 0001-Medium-CTDB-Use-logging-syntax-for-ctdbd-bsc-981863.patch
* Fri May 20 2016 jengelh@inai.de
- Remove redundant %%clean section. Ensure systemd-tmpfiles is run.
* Tue May  3 2016 kgronlund@suse.com
- Update to version 3.9.7+git.1461938976.cb7c36a:
  + High: managing "Elastic IP" for EC2 instances
  + High: managing "Secondary Private IP" for EC2 instances
  + Low: VirtualDomain: fix unnecessary error when probing nonexistent domain
  + Low: mysql: Handle non-standard mysql server port
  + Low: Fix protential error for RA:nagios
  + Medium: iSCSILogicalUnit: Fix when using rbd store.
  + Low: iSCSILogicalUnit: Add tgt_bsopts parameter.
  + Low: Don't send Inaccessible real server e-mails in fork=yes mode
* Tue Apr 26 2016 kgronlund@suse.com
- Update to version 3.9.7+git.1461679689.18a78f5:
  + Medium: symlink: Handle missing directories in target (bsc#973054)
  + oracle: "shutdown immediate;" is needed after cleanup to be able to recover from the ORA-01081 error
  + oracle: inform user that monprofile must start with C## for container databases
  + tickle_tcp: Fix "Failed to open raw socket (Invalid argument)" issue
* Mon Mar 21 2016 kgronlund@suse.com
- Update to version 3.9.7+git.1458512170.48350a9:
  + High: SAPDatabase: Add support for Oracle 12c (bsc#967380)
  + High: sapdb.sh evaluate parameter DBOSUSER also in start and stop methods (bsc#971914)
  + Low: SAPInstance: Update version support statement (bsc#965872)
  + Low: apache: ensure readable $TESTCONFFILE
  + Added iSER enabled portal support
  + quote vgchange options
  + Added pgagent RA
  + galera: fix monitoring of joining node for long running SST
  + galera: don't bootstrap from a node with no grastate.dat when possible
  + oralsnr: fix status check fail when username is more than 8 characters long
* Fri Feb 19 2016 kgronlund@suse.com
- Update to version 3.9.7+git.1454950092.6f56933:
  + Dev: ocft: include runocft to the tarball
* Wed Feb  3 2016 kgronlund@suse.com
- Update to version 3.9.7+git.1454497075.e697f43:
  + Medium: nfsserver: fix monitor for systemd
  + galera: force crash recovery if needed during last commit detection
  + galera: prevent recovered nodes from bootstrapping cluster when possible
  + galera: remove bashism
  + Add portal check to open_iscsi_get_session_id()
* Thu Jan 28 2016 kgronlund@suse.com
- Update to version 3.9.7~rc1+git.1453889774.3446b99:
  + Low: ldirectord: Fix unset failcount error (bsc#962795)
* Mon Jan 18 2016 kgronlund@suse.com
- Update to version 3.9.6+git.1452867140.fc8ace0:
  + SAPDatabase: Add Oracle 12 to list of supported databases (bsc#953991)
  + High: clvm: fix issue with only first option of daemon_options being used
  + High: mysql: fix grep failure on MySQL5.6 or higher when checking read_only variable
  + Medium: sg_persist: remove uncalled for ocf_run calls
  + Medium: ocf_shellfuncs: suppress bash specific trace_ra log on dash
  + Medium: ocf-rarun: replace error log messages with calls to ocf_exit_reason
  + Medium: nfsserver: do redhat specific stuff on redhat
  + Medium: iscsi: replace error log messages with calls to ocf_exit_reason
  + Medium: oracle/oralsnr: replace error log messages with calls to ocf_exit_reason
  + Medium: pingd: replace error log messages with calls to ocf_exit_reason
  + Medium: Raid1: replace error log messages with calls to ocf_exit_reason
  + Medium: pgsql: replace error log messages with calls to ocf_exit_reason
  + Medium: exportfs: don't increment fsid for single directory
  + Medium: Filesystem: add overlay as supported filesystem
  + Medium: mysql: When mysql has been already stopped, mysql is finished normally.
  + Low: pgsql: fix to be used valid charcters when the invalid characters is used in replication_slot_name.
  + Low: mysql: fix missing variables
  + Low: mysql: tmpfile is leaking when set the OCF_CHECK_LEVEL to 10
  + Low: nfsserver: prevent error messages on platforms without rpcuser (again)
  + Low: pgsql : fix invalid log message
  + Low: apache-conf: handle parsing includes with values in quotes
  + Low: pgsql: properly show default values in meta-data
  + Low : Changed the check handling of pid to the common function.
  + Low : Changed it that the message which pid file deleted repeated and did not appear
  + Low: pgsql: fix grep failure when using pacemaker 1.1.12
  + LVM: Allow vgck failures if partial
  + LVM: Correct grammar in partial_activation descriptions
  + IPaddr2: Add IPv6 DAD collision detection
  + VirtualDomain: New resource attributes migration_speed and migration_downtime
  + Nagios Resource Agent
  + Fix 90s wait/killing of databases containing the name of the database being killed, and added cleanup code to kill remaining listener process.
  + mysql.sh: wait up to startup_wait seconds before failing if mysqld startup is slow
- Remove patches that have been merged upstream
  - Remove 0001-nfsserver-Add-EXEC_MODE-for-systemd-without-nfs-lock.patch
  - Remove 0002-nfsserver-Use-rpc-statd.service-for-NFS-locking-in-E.patch
* Tue Nov 24 2015 kgronlund@suse.com
- nfsserver: Use rpc-statd.service for NFS locking in EXEC_MODE=3 (bsc#955114)
- Add 0002-nfsserver-Use-rpc-statd.service-for-NFS-locking-in-E.patch
* Fri Nov 20 2015 kgronlund@suse.com
- nfsserver: Add EXEC_MODE for systemd without nfs-lock.service (bsc#955114)
- Add 0001-nfsserver-Add-EXEC_MODE-for-systemd-without-nfs-lock.patch
* Wed Oct 14 2015 kgronlund@suse.com
- Update to version 3.9.6+git.1444655379.5f44ac6:
  + send_arp: fix for infiniband, re-merge from upstream iputils arping
  + Medium: docker: Correction of the mistake of the variable name.
  + Low: s/ist/is typo fix
  + Low: syslog-ng: set default binary to /sbin/syslog-ng
  + galera: start joining nodes during 'monitor' to allow long-running SST
  + galera: document the bootstrap flow
* Wed Sep 16 2015 kgronlund@suse.com
- Update to version 3.9.6+git.1442374860.7f3628a:
  + Low: pgsql: set_master_score use an undefined variable($target).
  + Fix exec_sql errors like "unknown variable select pg_ " on ubuntu
  + Low: findif.sh: Allow + and - as broadcast arguments (bsc#940931)
  + Low: IPaddr2: Describe + and - broadcast arguments (bsc#940931) (#656)
  + galera: add support for MYSQL_HOST and MYSQL_PORT from clustercheck
* Tue Sep  8 2015 kgronlund@suse.com
- Update to version 3.9.6+git.1441596198.a62fc5a:
  + High: clvm: activate_vgs option for enable/disable of automatic vg activation
  + High: IPsrcaddr: return correct error code during stop when misconfigured
  + Fixed redis start operation if replication sync takes > 20 seconds
  + Made 'slave of XXX' wait forever (demote)
  + Low: pgsql: eliminate duplicate "ocf_exit_reason".
  + Docker: remove trailing spaces
  + Docker: fix docker existance test report error
  + High: redis: avoid 0 byte dump.rdb start failures
  + High: dhcpd: use correct default chroot for rhel based systems
  + orainstance.sh: interpret listener stop results correctly
  + Support RozoFS
  + Low: pgsql: replace "output=su ..." to a new function, exec_sql()
  + Medium: pgsql: delete an old replication slot when creating the slot.
  + iSCSILogicalUnit: add check for leftover target/core entries for lio-t
  + iSCSILogicalUnit: return OCF_NOT_RUNNING on monitor if backing path does not exist
  + iSCSILogicalUnit: when deleting a LUN or initiator fails with lio-t, proceed with warning
  + iSCSITarget: properly create portals for lio-t implementation
  + more accurate search results when tag is not specified
  + Fix "docker images" difference between distro
  + more strictly image check for repository, name, and tag
  + Use runuser inteald of su command for SELinux enforcing mode
  + Use runuser command instead of su in order to run selinux enforcing mode.
  + Medium: CTDB: Preserve permissions on smb.conf (bsc#935253)
  + High: redis: use required client pass word when set
  + Added "maxfiles" parameter for increasing maximum number of open files (for ulimit -n)
  + Low: update contact info
  + pgsql: Fix return code override in pgsql_real_start()
  + [high] Fix redis password parser
* Fri May  8 2015 kgronlund@suse.com
- Update to version 3.9.6+git.1430920897.b7ea7f9:
  + High: galera: make sure to clear last known sequence number promote is even attempted
  + High: galera: properly redetect bootstrap after demote
  + High: ethmonitor: link_status_only option for skipping RX counter and arping tests
* Tue Apr 21 2015 kgronlund@suse.com
- Update to version 3.9.6+git.1429568091.f79322c:
  + Medium: multiple: make sure that the pidfile directory exist
  + orainstance.sh: Fix process name grep in exit_idle
  + Low: pgsql: fix check_wal_receiver to prevent incorrect "ERROR" status display and output WARN log in the master
  + Low: allow rgmanager lvm agent to handle hostname aliases
  + Fix rmq_join_list to only return online nodes
  + Medium: pgsql: Support replication slots
  + Low: pgsql: add validation check for replication slot.
  + Low: redis: smarter config argument default
  + Fix: redis: reliable shutdown.
  + Low: redis: loosen advertised default monitor timeout seconds
  + Fix: redis: do not attempt to demote if redis is dead
  + Low: redis: make sure to always delete master score on stop
  + Low: redis: reconnect to new master after promotion
  + High: redis: only connect to active master instances
  + High: redis: wait_last_known_master option for redis agent.
  + Low: redis: prevent bash syntax errors and lower priority some log messages
  + High: galera: retrieve last sequence number without using read-only mode
  + Fix return code in asterisk_monitor #2
* Tue Apr  7 2015 kgronlund@suse.com
- Update to version 3.9.6+git.1427133197.6897c9c:
  + High: introducing rabbitmq clustering agent
  + Filesystem: fix misspelled log messages
  + Filesystem: support overlayfs
  + Medium: sg_persist: do use the binary parameter
  + Medium: dnsupdate: use the advertised nsupdate_opts
  + build: add missing RAs to makefiles
  + Fix: nfsserver: avoid re-tagging nfs sysconfig with autogen header
  + nfsserver: merge options into existing sysconfig/nfs
  + portblock: portno param can be a string like 137,138
  + portblock: replace ancient heartbeat config with crm configure
  + portblock: clarify TCP RST vs ICMP port unreachable
  + portblock: capitalize "Linux"
  + portblock: ports can't be "turned off"
  + portblock: fix typo
  + Medium: VirtualDomain: enforce C locale in force_stop
  + Low: VirtualDomain: Fixed to correctly get the return code of the "virsh destroy" command
  + redis: retry on unknown error when starting
  + bash bug fix, no arbitrary stop timeout, placeholder master during election period
  + build: update ChangeLog for 3.9.6
  + Medium: VirtualDomain: enforce C locale in status
  + CTDB: Change default socket location to CTDB's expected default.
  + CTDB: Whitespace cleanup.
  + Medium: VirtualDomain: add migrate_options parameter
  + nginx: Allow different URLs for level 10 and 20 monitor
  + build: update ChangeLog for 3.9.6-rc1
  + Low: nfsserver.sh: for rgmanager nfs agent, strip off trailing '/' from path option
  + mysql.sh: Allow MySQL to run as user other than mysql
  + fs-lib.sh: Fix missed detection of write failure
  + Low: postgresh-8.sh: fixes rgmanager pgsql agent's ability to detect user group
  + Modify manual for negotiatetimeout
  + Medium: iscsi: run iscsi discovery only when necessary
  + High: VirtualDomain: save the config before virsh undefine (bnc#891915)
  + RA and ocft for sg_persist
  + ldirectord: Add Install section for systemd unit file.
  + Use calculated default pidfile.
  + Removed 'pidof' because it's not cross-platform compatible
  + Using 'check_binary'
  + ldirectord: modify manual and sample for Radius check
  + ldirectord: Fix can not remove virtualservice when stopping ldirectord via systemctl.
  + findif.sh: Use the most specific matching route
  + Low: LVM: volgrpname is unique (meta-data update)
  + Medium: ldirectord: Get correct user for sending email (bnc#910497)
  + Low: configure.ac: remove POSIX-incompatible command
  + Low: add variables OCF_RA_VERSION_MAJOR, OCF_RA_VERSION_MINOR, OCF_EXIT_REASON_PREFIX OCF_RESOURCE_TYPE, and OCF_RESOURCE_PROVIDER in ra-dev-guide.txt based on pacemaker source
  + Low: add a few more references to notify in ra-dev-guide.txt
  + #526, do not set write_back when creating backstore/block
  + Medium: portblock: Feature: reset_tcp_on_unblock_stop
  + Low: nfsserver: prevent error messages on platforms without rpcuser
  + Medium: Xen: fix regression with xm and quoting (lf#2671)
  + re-add LXCpre1.0 logic
  + remove check for unused binary
  + fix for missing lxc-ps command in ocf:heartbeat:lxc
  + Low: Route: some unique attributes are not unique
  + Log domain status in debug mode for xl and xen-list
  + Medium: IPaddr2 findif: accept dotted quad netmask
  + Low: mysql: document use of notify metadata attr for master/slave
  + Medium: VirtualDomain: For Xen, prefer xl to xen-list (boo#901453)
  + Medium: Xen: Use xl list $domain return code in status check (boo#901453)
  + Low: pgsql: PostgreSQL 9.3 compatibility for unix_socket_directories
- Remove merged patches:
  + findif-multiple-routes-bnc892755.patch
  + fix-sg_persist-commented-byLars.patch
  + fix-sg_persist-demote-error.patch
  + fix-sg_persist-devs-required-and-not-defined.patch
  + fix-sg_persist-for-code-normalization.patch
  + resource-agents-new-sg_persist.patch
  + sg_persist-ocft-not-configure-iscsi.patch
* Thu Dec  4 2014 lwang@suse.com
- fix fix-sg_persist-devs-required-and-not-defined.patch
  to eliminate build warning: script-without-shebang
* Fri Nov 21 2014 kgronlund@suse.com
- Update to upstream cs v3.9.5-631-g992ca06
  - High: Introduces the docker agent to manage docker containers in an HA environment
  - High: mysql: report error when validation fails during monitor yet pid is still active
  - High: mysql-common: avoid use of check_binary in common validation function.
  - Medium: ocf-shellfuncs: set HA_LOGD depending on HA_use_logd
  - Low: VirtualDomain: downgrade error msg during probe
  - Modified replication_user description: RELOAD privilege is required for RESET SLAVE or RESET SLAVE ALL command.
  - lvm_by_vg.sh: Only strip tag on stop if we are owner
  - Low: pgsql: PostgreSQL 9.3 compatibility for unix_socket_directories
  - Medium: Xen: Use xl list $domain return code in status check (boo#901453)
  - Medium: VirtualDomain: For Xen, prefer xl to xen-list (boo#901453)
  - Low: mysql: document use of notify metadata attr for master/slave
* Thu Oct 16 2014 kgronlund@suse.com
- Update to upstream cs v3.9.5-589-gb644395
  - High: iSCSILogicalUnit: fixes syntax errors
  - High: galera: do not ignore specified check_password
  - Fix: shellfuncs: fix syntax error caused by exit_reason support for dash shell.
  - Fix: ocf_exit_reason: implicit format string "%%s" for single argument version
  - Fix: ha_log: drop global __ha_log_ignore_stderr_once hack
  - $((var++)) breaks in the dash shell
* Tue Sep 16 2014 kgronlund@suse.com
- Update to upstream cs 5652c04 (bnc#889914)
  - fix output redirection of 'anything' resource
  - Medium: mysql: fix unexpected operation error that caused by MySQL client timeout.
  - Middle: anything: Prevent stop failure, even if the job takes time to stop.
  - High: doc: Add pcs to man page example section
  - Remove use of non standard command usleep
  - High: ethmonitor: exit reason support
  - High: Exit reason string support updates
  - Medium: Build: add --compat-habindir option for HA_BIN backward compatibility
  - Low: iSCSITarget: Support exit reason string
  - High: iSCSITarget: monitor operation must pass before start is considered complete
  - Low: iSCSILogicalUnit: support ocf exit reason string
  - High: iSCSILogicalUnit: monitor operation must pass before start is considered complete
  - Merge pull request #482 from davidvossel/iscsi-updates
  - High: iSCSILogicalUnit: Improves the resiliency of LIO iSCSILogicalUnit
  - Low: iSCSILogicalUnit: fix inconsistent formatting
  - High: Filesystem: when loading kernel modules wait for filesystem to initialize
  - High: ocf-shellfuncs: Remove action_filter from ocf_exit_reason parameters
  - High: ethmonitor: add infiniband status monitoring support
  - Medium: Xinetd: refine exit codes when xinetd is stopped
  - Low: ethmonitor: Add pcs example with crmsh example in metadata
  - Low: ethmonitor: Improve logging during monitor operation to help determine reason for failure
  - High: clvm: automatically set lvm.conf's locking_type=3
  - High: VirtualDomain: exit reason support
  - High: IPaddr2: support ocf_exit_reason
  - High: exportfs: support exit reason string
  - High: nfsserver: support exit string in nfsserver agent
  - High: nfsnotify: set exit reason strings in nfsnotify agent
  - High: ocf-binaries: have 'check_binary' set exit reason
  - High: ocf-shellfuncs: Log exit reason to log facilities as well as stderr
  - Revised IPv6 workaround code #379
  - Low: ethmonitor: Use consistent formatting
  - Low: ethmonitor: Increase recommended default timeout settings
  - Low: ethmonitor: Perform first monitor during start action
  - Low: nfsserver: only set rquotad options when port is set
  - separate lio and lio-t start
  - add targetcli support to iSCSI resource agents
- Remove merged patch: xen-replace-xm-with-xl.patch
- upstream cs: v3.9.5-578-g5652c04
* Thu Aug 28 2014 kgronlund@suse.com
- Add COPYING.LGPL
* Wed Aug 27 2014 kgronlund@suse.com
- Disable monitoring-plugins-metadata
* Tue Aug 26 2014 kgronlund@suse.com
- Add patch findif-multiple-routes-bnc892755.patch
  - findif.sh: Use the most specific matching route (bnc#892755)
* Thu Aug 14 2014 kgronlund@suse.com
- drop dependency on monitoring-plugins-udp since it is folded into
  monitoring-plugins-tcp
* Thu Aug  7 2014 kgronlund@suse.com
- Rename nagios-plugins-metadata to monitoring-plugins-metadata (bnc#890337)
* Tue Aug  5 2014 kgronlund@suse.com
- Medium: Xen: Properly quote domain name in call to create
- Updated patch: xen-replace-xm-with-xl.patch
* Tue Aug  5 2014 kgronlund@suse.com
- Low: oracledb.sh: remove process path from process search results
- Low: Dummy: add sample usage of 'ocf_exit_reason'
- High: shellfuncs: set exit error reason string
- Medium: oracle: fix setting monitor user profile for other languages (nls)
- Low: LVM: Warn users about the danger of lvmetad
- Low: nfsnotify: fixes error message output
- Low: nfsserver: fix usage of rquatad_port option
- Low: nfsserver: warn user when nfs port options can not be set
- Low: nfsserver: fixes issue with proc/fs/nfsd not being mounted during start on some distros
- Low: ocf-shellfunctions: handle local nodename when version has distro postfix
- Low: bind-mount.sh: Update meta-data to reflect required arguments
- Low: mysql: Refactoring mysql logic into common library that can be shared with galera agent
- Medium: oracle: reset MONUSR password if it expired
- High: oracle: try as sysdba if monitor as MONUSR fails
- High: oralistener.sh: Do not fail during stop if listener has already stopped
- Low: oracledb.sh: Fix exit_idle loop to exit process wait loop correctly
- Low: orainstance.sh: the exit_idle function was a no-op because of a malformed grep search
- Low: oralsnr: ignore listener case during grep for pid
- dropped merged patches:
  - 0001-High-oracle-Require-monitoring-user-as-parameter-bnc.patch
  - 0001-Medium-VirtualDomain-Try-xen-list-if-no-emulator-is-.patch
  - 0001-Medium-mysql-Update-mysql-with-more-sensible-default.patch
  - apache-fix-bnc884674.patch
- upstream cs: v3.9.5-508-g4f369d8
* Tue Aug  5 2014 kgronlund@suse.com
- Update license to include GPL-3.0+
* Tue Aug  5 2014 kgronlund@suse.com
- Reintroduce nagios plugins metadata (bnc#890337)
  - Add nagios-plugins-metadata.tar.bz2
* Mon Jul 21 2014 kgronlund@suse.com
- Revised fix for apache RA on SUSE distributions (bnc#884674)
- Add apache-fix-bnc884674.patch
* Tue Jul  8 2014 kgronlund@suse.com
- Medium: VirtualDomain: Try xen-list if no emulator is set (bnc#885292)
- Add 0001-Medium-VirtualDomain-Try-xen-list-if-no-emulator-is-.patch
* Tue Jul  8 2014 kgronlund@suse.com
- High: Xen: Enable use of xl instead of xm if available (bnc#882548)
- Add: xen-replace-xm-with-xl.patch
* Tue Jul  8 2014 kgronlund@suse.com
- Medium: exportfs: allow multiple exports
- High: nfsserver: Support new NFS Active Passive and Active Active use-cases.
- Low: nginx: Fix incorrect parameter name
- Reintroduce Xen RA (bnc#882548)
- dropped merged patches:
  - remove 0001-ctdb-add-ctdb_rundir-parameter-and-create-on-startup.patch
  - remove 0001-Medium-VirtualDomain-Add-support-for-qemu-dm-as-emul.patch
  - remove apache_conditional_initd_check-bnc884674.patch
- upstream cs: v3.9.5-453-g9eb8c17d467e
* Fri Jul  4 2014 ddiss@suse.com
- Create the CTDB runtime state directory on startup; (bnc#885049).
  + added 0001-ctdb-add-ctdb_rundir-parameter-and-create-on-startup.patch
* Fri Jul  4 2014 kgronlund@suse.com
- Medium: VirtualDomain: Add support for qemu-dm as emulator (bnc#885292)
- add 0001-Medium-VirtualDomain-Add-support-for-qemu-dm-as-emul.patch
* Tue Jul  1 2014 kgronlund@suse.com
- Medium: apache: Check before calling init.d script (bnc#884674)
- add apache_conditional_initd_check-bnc884674.patch
* Wed Jun 25 2014 kgronlund@suse.com
- High: conntrackd: allow probe to return OCF_RUNNING_MASTER
- High: Filesystem: Add force_unmount option
- High: fs-lib.sh: Force kill processes with access to shared libraries on mount point
- High: VirtualDomain: restore advertised start and stop timeout values to a sane value.
- Exclude Xen resource agent (bnc#882548)
- Merged upstream:
  - Removed 0001-Low-ldirectord-fix-the-list-output-to-include-ops-fl.patch
  - Removed 0001-ldirectord-Add-systemd-unit-file-bnc-863250.patch
- Dropped (bnc#882548)
  - Removed xen-replace-xm-with-xl.patch
- upstream cs: v3.9.5-432-g07aeed7c9035
* Sun Jun 15 2014 kgronlund@suse.com
- Update xm/xl patch with additional fixes (bnc#882548)
- Modified: xen-replace-xm-with-xl.patch
* Fri Jun 13 2014 kgronlund@suse.com
- High: Xen: Replace use of xm with xl (bnc#882548)
- Add: xen-replace-xm-with-xl.patch
* Mon Jun  9 2014 kgronlund@suse.com
- rgmanager/fs: typo preventing passing some mount opts
- nfsserver.sh: add an optional option for rpc.statd
- fs-lib.sh: Fix usage of findmnt to work for filesystems containing bind mounts
- addition of bind-mount resource agent for rgmanager
- postgres-8.sh: add startup_wait option to rgmanager postgres agent
- upstream cs: v3.9.5-410-g6f1dffee54d1
* Fri May 30 2014 lwang@suse.com
- sg_persist: change sg_persist ocft not configure isci and let user prepare it manually
  add sg_persist-ocft-not-configure-iscsi.patch
* Fri May 30 2014 lwang@suse.com
- bnc#880726: sg_persist devs required and not defined when define by configuration file
  add fix-sg_persist-devs-required-and-not-defined.patch
* Tue May 27 2014 lwang@suse.com
- bnc#879881: fix sg_persit demote error
  add fix-sg_persist-demote-error.patch
* Fri May 23 2014 kgronlund@suse.com
- Updated 0001-ldirectord-Add-systemd-unit-file-bnc-863250.patch
  - Use absolute paths for touch and rm
- ldirectord: Add missing dependency on perl-IO-Socket-INET6
* Fri May 23 2014 jsegitz@novell.com
- added necessary macros for systemd files
* Mon May 19 2014 kgronlund@suse.com
- rgmanager/fs: typo preventing passing some mount opts
- nfsserver.sh: add an optional option for the rpc.statd listening port
- iscsi: iscsi status fails with open-iscsi with support for flash (bnc#878039)
- nfsserver: let systemd service files handle lock notifications
- vm.sh: Monitor kvm resources without requiring libvirtd
- Calculate stop loop according stop timeout
- Added kamailio resource agent
- IPaddr2: fix error msg from manual clone/incarnation # era
- clvm: Properly detect directory for vg tools
- Add IPv6 http(s) health checking to ldirectord
- nfsserver.sh: On stop, kill sm-notify so /var/lib/nfs/statd can be unmounted
- VirtualDomain: Allow monitoring of lxc domains without libvirtd
- named.sh: Fix issues running named daemon as a non-root user
- VirtualDomain: cache domain emulator after start
- CTDB: do not fail monitor operation when ctdb socket does not exist
- exportfs: Make unlock_on_stop_default=1 (bnc#864263)
- Stateful: Clean up implementation of Stateful (bnc#867372)
- dnsupdate: resource agent for IP take-over via dynamic DNS
- upstream cs: v3.9.5-404-g61a2ccc8b7b1
- Updated resource-agents-nfsserver-sle11.patch
- Removed 0015-Medium-exportfs-Make-unlock_on_stop_default-1-bnc-86.patch
* Thu May  8 2014 ro@suse.de
- use _rundir macro
* Wed Apr  2 2014 lwang@suse.com
-Fate#312345-add fix-sg_persist-commented-byLars.patch
* Fri Mar 28 2014 kgronlund@suse.com
- mysql: Update mysql with more sensible defaults (bnc#863844)
- added patches:
  * 0001-Medium-mysql-Update-mysql-with-more-sensible-default.patch
- removed patches:
  * resource-agents-mysql-sle11.patch
* Mon Mar 10 2014 kgronlund@suse.com
- exportfs: Make unlock_on_stop default to 1 (bnc#864263)
- added patches:
  * 0015-Medium-exportfs-Make-unlock_on_stop_default-1-bnc-86.patch
* Thu Feb 27 2014 kgronlund@suse.com
- ldirectord: Add systemd unit file (bnc#863250)
- ldirectord: fix the list output to include ops flag (bnc#847005)
- VirtualDomain: Fixes parsing domain name from xml file
- nfsclient.sh: Add 'sec=' as a valid exports option
- CTDB: Detect default persistent database directory
- CTDB: Ensure logfile directory exists so CTDB can start
- VirtualDomain: Attempt to determine vm status even when libvirt
  is unavailable
- apache.sh: Add ability to set custom httpd binary
- findif: Update default value for best_netmask
- VirtualDomain: avoid running "virsh uri" if hypervisor is set
- VirtualDomain: check process table for qemu-system-* too
- mysql: handle %%secs_behind = NULL
- logging: Fix syntax errors with logging functions in LVM and
  asterisk agents
- upstream cs: 935b92fd
- added patches:
  * 0001-Low-ldirectord-fix-the-list-output-to-include-ops-fl.patch
  * 0001-ldirectord-Add-systemd-unit-file-bnc-863250.patch
* Tue Feb 25 2014 kgronlund@suse.com
- oracle: Require monitoring user as parameter (bnc#850589, bnc#859683)
- added patches:
  * 0001-High-oracle-Require-monitoring-user-as-parameter-bnc.patch
- removed patches:
  * 0003-Medium-oracle-Create-profile-for-OCFMON-user-bnc-850.patch
  * 0004-High-oracle-Make-monitoring-user-configurable-bnc-85.patch
* Mon Feb 24 2014 lwang@suse.com
-Fate#312345-add fix-sg_persist-for-code-normalization.patch
* Thu Jan 23 2014 kgronlund@suse.com
- Remove 0001-Medium-CTDB-Default-ctdb-manages-samba-and-ctdb-mana.patch:
  Accidentally reintroduced obsolete patch
- Remove 0002-Medium-CTDB-Add-smb_fileid_algorithm-parameter-defau.patch:
  Accidentally reintroduced obsolute patch
* Wed Jan 22 2014 kgronlund@suse.com
- Add 0001-Medium-CTDB-Default-ctdb-manages-samba-and-ctdb-mana.patch:
  CTDB: Default ctdb manages samba and ctdb manages winbind to "yes", tserong@novell.com
- Add 0002-Medium-CTDB-Add-smb_fileid_algorithm-parameter-defau.patch:
  CTDB: Add smb_fileid_algorithm parameter, defaults=fsid (bnc#696978), tserong@novell.com
- Add 0003-Medium-oracle-Create-profile-for-OCFMON-user-bnc-850.patch:
  oracle: Create profile for OCFMON user (bnc#850589), kgronlund@suse.com
- Add 0004-High-oracle-Make-monitoring-user-configurable-bnc-85.patch:
  oracle: Make monitoring user configurable (bnc#859683), kgronlund@suse.com
- Add 0006-Revert-Low-build-Move-binaries-in-usr-lib-heartbeat-.patch:
  Revert move of heartbeat binaries to /usr/libexec
- ldirector: fix using service name instead of port number (bnc#836759)
- pgsql: Support for non-standard port and library locations
- Xen: retry domain lookup in repeating monitor and stop
- Xen: report error if the monitor does not find the guest
- VirtualDomain: support more virsh domstate output formats
- LVM: only remove missing PVs on stop when they belong to mirrors
- Raid1: disallow md raid arrays as clone resources to avoid data corruption
- Raid1: make clone prevention overridable similar to the Filesystem RA
- Filesystem: switch to use ocf_is_clone helper function
- varnish: Added support for ulimit -l and ulimit -n
- jboss: Monitor rotatelogs process and restart when it is stopped
- Pure-FTPd: Create pid directory if needed
- lxc: support up-to-date lxc-ps versions
- oracledb.sh: Fix process name grep in exit_idle
- oracledb.sh: Remove quotes around listener name
- oralsnr: Add tns_admin option for setting custom TNS_ADMIN path
- VirtualDomain: Fix ability to use default libvirt hypervisor without explicitly setting agent attribute
- VirtualDomain: Ensure it is possible to manage a libvirt domain defined outside of VirtualDomain
- nfsserver: nfsserver not starting due to missing etab file
- fs-lib.sh: Fixes failure to unmount local fs when process runs with cwd inside fs mount
- upstream cs: 468ed4f8
* Fri Jan 17 2014 lwang@suse.com
- fix a few lines for monitor
* Mon Jan 13 2014 kgronlund@suse.com
- Fate#312345-Add resource-agents-new-sg_persist.patch: RA for persistent
  SCSI reservation
* Tue Sep 10 2013 dmuhamedagic@suse.com
- Filesystem: add corosync as HA_cluster_type
- eDir88: multiple IP support (bnc#)
- apache: better handling of not installed apache
- jboss: add jboss_base_dir parameter to support multi-instances
  on JBoss 6
- jboss: stop the JBoss daemon by sending a signal on JBoss 6
- jboss: add run_command parameter to change the start up script
- jboss: add jboss_version parameter to support JBoss 6
- tomcat: use root as the default for tomcat_user instead of
  RUNASIS mode
- tomcat: multiple tomcat instances based on CATALINE_BASE
- VirtualDomain: no longer define a domain, but use "virsh
  create" to start it non-persistent
- pound: add parameter maxfiles to set ulimit
- apache: remove unnecessary and imperfect checks from
  validate_all (bnc#827927)
- pgsql: set only one node into sync mode when using 3 nodes or
  higher
- Raid1: stop arrays even with block device file missing
  (bnc#821861)
- oracle/oralsnr: explicitly require bash (bnc#825517)
- Raid1: set MDADM_NO_UDEV appropriately if udev is not used
- Raid1: wait for udevd to settle (bnc#821861)
- iSCSILogicalUnit: add tgt specific parameters bstype, bsoflags,
  device_type
- apache: Attempt graceful stop before -TERM signal
- LVM: Warn user if initrd is older than lvm.conf when using
  exclusive activation with tags
- LVM: Exclusive activation without clvmd using filtering with
  tags.
- named: Attempt to autogen /etc/rndc.key using rndc-confgen tool
- mysql: really use log setting (bnc#823095)
- mysql: test properly for failed process start (bnc#823095)
- LVM: Retry exclusive activation after deactivating vg
  cluster-wide
- LVM: Verify setup on start plus verify exclusive activation is
  possible
- Route: make Route RA IPv6 ready
- drbd: remove deprecated drbd agent
- tools: send_arp.libnet: reuse ARP packets (deb#701914)
- ethmonitor: correctly detect when the network is unplugged.
- Raid1: do not test for device existence in the stop operation
  (bnc#821861)
- VirtualDomain: Support saving and restoring virtual machine
  snapshot state files
- nfsserver: Cleanup shared nfs dir mount
- nfsserver: Enable file locking daemon when systemd is being
  used
- nfsserver: Maintain SELinux permissions on failover for nfs v3
  lock state
- nfsserver: Improve support for v3 file lock recovery
- nfsserver: Add systemd unit-file support when init scripts are
  not present
- apache: add pidfile directive when not present in config file
- VirtualDomain: Properly detect defined lxc domains
- iSCSILogicalUnit: add lio_iblock parameter.
- upstream cs: 3cafd1
* Thu Aug  1 2013 tchvatal@suse.com
- Run over format_spec_file service.
* Tue Mar 26 2013 dmuhamedagic@suse.com
- ocf-shellfuncs: use $HA_VARLIB as default destination for trace
  files
- VirtualDomain: allow for custom migrateport
- IPaddr2: support nic:iflabel format in nic parameter
- upstream cs: ddad46 (v3.9.5)
* Tue Feb  5 2013 dmuhamedagic@suse.com
- ocf-shellfuncs: RA tracing
- IPaddr2: make sure that some ARP send program runs
- pgsql: add check_wal_receiver parameter
- pgsql: support starting as Hot Standby
- nfsserver: improve rpc.statd support
- nfsserver: add option -n for rpc.statd (bnc#794479)
- nfsserver: make the retry time for sm-notify configurable
- nfsserver: make sm-notify running in the foreground configurable
- exportfs: handle '<world>' exportfs embelishment for '*' (bnc#791690)
- jboss: set JAVA_OPTS correctly
- pound: use correct default for control-binary
- pound: No error when stopping pound and no pound is running
- Squid: support systems using IPv6
- Xinetd: do not fail in stop if the daemon is not running
- Xinetd: improve finding Xinetd process (thanks to Vadym Chepkov)
- SendArp: add background parameter
- SendArp: fix monitor
- ocft: print the actual case names when testing
- ocft: make only the updated test-case file
- ocft: add "incremental" mode (ocft test -i)
- include a copy of LGPL license file
- upstream cs: e265f0 (3.9.5 rc1+)
* Wed Nov 28 2012 dmuhamedagic@suse.com
- zabbixserver: RA for zabbix servers management
- IPaddr2: use better test for infiniband (bnc#783353)
- IPaddr2: replace the findif binary by findif.sh
- IPaddr2: add IPv6 support
- IPaddr2: really send arps in background if requested
- IPaddr2: use send_arp instead of ipoibarping if not available
- Raid1: discover block size for dd (bnc#781137)
- Xen: repair node_ip_attribute use
- SAPDatabase: improvement of cleanup of saphostctrl process
- SAPInstance: monitor-master not advertised (bnc#782482)
- SAPInstance: don't wait for timeout if the stop attempt failed
- SAPInstance: failes on sapcontrol message Unauthorized (bnc#782486)
- tomcat: Correction of the process alive monitoring.
- ldirectord: Added READDQUIESCENT parameter
- Squid: fix getting PIDs of squid processes (lf#2653)
- portblock: use end-of-word instead of space at the end of the line
- named: use pgrep instead of searching in ps(1) output
- named: fix monitor if named_rootdir is set to /
- tools: add test-findif.sh
- tools: add send_ua binary for IPv6 support in IPaddr2
- ocft: new test for Raid1
- upstream cs: 4890c9 (3.9.4)
* Thu Sep 27 2012 dmuhamedagic@suse.com
- dhcpd: new RA to manage ISC DHCP servers
- pound: new RA for Pound HTTP/HTTPS reverse-proxy and load-balancer
- ocf-rarun: add the RA driver
- apache: create /var/run/apache2 if it doesn't exist
- conntrackd: rename parameter "conntrackd" to "binary"
- conntrackd: resync from other hosts in start
- exportfs: allow expanding the fsid parameter to produce correct
  exportfs options
- exportfs: cleanup exportfs cache on stop (bnc#770210)
- exportfs: don't grow /var/lib/nfs/rmtab indefinitely (bnc#754067)
- Filesystem: add nfs4 to the list of well known types
- Filesystem: allow to force cloning for local mounts
- Filesystem: fix determining if the device is a block device
- Filesystem: improve read/write checks for CHECK_LEVEL 10, 20
- Filesystem: include ceph in the list of non-blockdev filesystems
- Filesystem: remove a status file only when OCF_CHECK_LEVEL is set to 20
- Filesystem: support ceph
- IPaddr2: fix regression introduce in d93b5fd, nic=lo always "stopped"
- IPaddr: remove colon at the end of the interface name
- IPv6addr: always use the provided nic and cidr_netmask when specified
- iscsi: add try_recovery parameter
- iscsi: check session status in monitor
- iscsi: do discovery in start only
- iscsi: do not rely on iscsid.startup being set correctly (bnc#751783)
- iscsi: don't fail on stop of the iscsi server fails
- iscsi: use iscsiadm -m session -r in stop
- iSCSILogicalUnit: correctly match for target IQN and backing
  device name (iet and tgt)
- iSCSITarget: treat an empty "implementation" parameter specially
- jboss: implement rotating of console log
- ldirectord: precedence error with perl v5.8.8 in IPv6 code
- lxc: fix LXC_status to work with lxc-0.7.5 or later
- mysql: fix validation return codes
- mysql: improve replication support
- mysql: support 5.5 slave status message format
- mysql-proxy: add in-depth monitoring
- mysql-proxy: add the 'plugins' parameter
- mysql-proxy: create pid/socket directories if needed
- nfsserver: add a new parameter for the rpc_pipefs mount point
- nfsserver: don't run sm-notify in foreground (bnc#759616)
- nfsserver: NSM state files correctly populate
  /var/lib/nfs/sm.ha (bnc#684139)
- nfsserver: Support of multiple IP addresses (bnc#684143)
- oracle: connect as a regular user in monitor
- oracle: ignore password expiry warning in monitor (bnc#770250)
- oracle: improve managing IPC objects
- oracle: improve matching instance specific files and processes
- oracle, oralsnr: get rid of eval
- oralsnr: match only one (our) listener process
- pgsql: add option archive_cleanup_command
- pgsql: add option recovery_end_command
- pgsql: support for replication
- pgsql: support multi-instance in replication mode
- Raid1: manage multiple arrays
- Raid1: stop processes using raiddev
- SAPDatabase: add support for Sybase ASE and SAP HANA database
- SAPDatabase: new method for checking responsiveness of saphostexec
- SAPDatabase: make use of saphostagent
- sfex: sfex_init fails on a 64 bit big endian platform (lf#2647)
- slapd: always set the exit code correctly in monitor
- slapd: Gracefully handle config check during probe
- slapd: pass bind_dn correctly to ldapsearch
- tomcat: Correction of the time-out level of the stop processing.
- VIPArip: fix exit codes
- VIPArip: make start idempotent
- VirtualDomain: honor virsh "in shutdown" state
- VirtualDomain: if the configuration file is missing on stop
  exit with success
- Xen: add support for HVM ACPI graceful shutdown
- Xinetd: reimplementation
- Tools: send_arp.libnet: fix for big endian platforms (bnc#721334)
- Tools: SendArp: exit with the right code when not properly configured
- ocft: new tests for mysql-proxy, named, IPv6addr, oracle, Raid1, Xinetd
- upstream cs: 810c9b
* Fri Jun 29 2012 darin@darins.net
- added resource-agents require to ldirectord as it's init script
  requires /etc/ha.d/shellfuncs which that package provides
* Tue Feb 14 2012 tserong@suse.com
- ocf-shellfuncs: fix loglevel variable scope in ha_log
- exportfs: fix monitor action for special characters and common
  suffixes
- apache: add support for IPv6 in monitor
- iscsi: don't fail in stop or monitor if the portal is
  ambiguous (bnc#740718)
- ocf-tester: add -d and -q options
- Medium: Tools: findif: Use most specific matching route (bnc#740738)
- ldirectord: Allow IPv6 for NNTP, requires perl-IO-Socket-INET6 (bnc#669412)
- SAPInstance/SAPDatabase: fix unique attribute in metadata (bnc#737673)
- IPv6addr: handle a link-local address properly in send_ua
- iSCSILogicalUnit: fix default for scsi_sn
- named: make monitor work with IPv6 interfaces
- slapd: exit with the right code if validation fails (it used to
  exit always with the generic error code)
- upstream cs: de3074
* Thu Dec 15 2011 tserong@suse.com
- Add /usr/lib/tmpfiles.d/resource-agents.conf to ensure temp dir
  exists when using systemd (bnc#734760)
* Mon Dec 12 2011 dmuhamedagic@suse.com
- varnish: new resource agent
- LVM: force dmevent monitoring for clones
- Filesystem: repair the fast_stop parameter use (its value has
  always been false)
- slapd: prevent possible timeout in stop (wrong logic in stop)
- upstream cs: 72fdc8
* Fri Nov 25 2011 dmuhamedagic@suse.com
- asterisk: new resource agent
- IPaddr: add back the local_start/stop_script code
- iscsi: proceed if iscsid is not running if iscsid.startup is
  present in iscsid.conf
- mysql: check mysql status more thoroughly before stopping
- jboss: add the java_opts parameter for java options
- VirtualDomain: add a functionality that modifies utilization of
  resource automatically
- Tools: ocft: new option Agent, corresponding configs update
- doc: Add RA developer's guide
- move NodeUtilization to Pacemaker
- upstream cs: 1f8f3d
* Fri Nov 18 2011 jshi@suse.com
- Implemetation of Dynamic utilization detection and setting.
  Based on FATE#310117 and FATE#310115.
* Tue Nov  8 2011 xwhu@suse.com
- cleanup sfex_uuid.patch
* Mon Nov  7 2011 dmuhamedagic@suse.com
- tomcat: remove pidfile before start, it may prevent some tomcat
  releases from starting
- ocft: new options variable and cleanup-agent, var/unvar renamed
  to env/unenv, corresponding configs update
- upstream cs: 5599aa
* Mon Oct 31 2011 xwhu@suse.com
- fate#311000, sfex_daemon accept "-u $uuid". When assiging $uuid
  as a parameter, $lock_index is ignored.
* Mon Oct 24 2011 dmuhamedagic@suse.com
- slapd: wait in start for the service to come up
- apache: fix sysconfig includes & enable status for default SUSE conf
- upstream cs: 80b640
* Mon Oct 10 2011 dmuhamedagic@suse.com
- named: new resource agent
- Tools: send_arp.libnet: fix for big endian platforms (bnc#721334)
- rsyslog: new RA to manage rsyslog servers
- slapd: new RA to manage OpenLDAP servers
- Xen: wait in migrate_from for the migration to finish instead
  of bailing out immediately
- conntrackd: test for socket existence in monitor instead of
  process grep
- postfix: multiple fixes and improvements
- upstream cs: 6c24ae
* Tue Sep 20 2011 tserong@suse.com
- Filesystem: add tmpfs to the list of supported filesystems
- exportfs: fix adding the fsid parameter to options
- pgsql: fix meta-data the config param type in meta-data
- IPaddr: don't search for the IP address in the route table on
  remove
- CTDB: Improve monitor op (check output of ctdb status, bnc#712192)
- CTDB: Set ctdb_start_as_disabled=no by default (bnc#712410)
- Filesystem: add support for glusterfs (lf#2620)
- ocf-shellfuncs: fix wrong logic introduced in commit 8468b5
  (fixes wrong cluster prefix in log messages)
- Filesystem: don't use direct dd option in monitor depth 20 for
  non-blockdevice fs
- CTDB: Add smb_fileid_algorithm parameter
- Implemetation of Dynamic utilization detection and setting.
  Based on FATE#310117 and FATE#310115.
- ocf-shellfuncs: add RA instance name to ocf_log/debug
- Raid1: support for multiple MD arrays, as specified in raidconf
- ethmonitor: new RA to monitor network interfaces
- conntrackd: new RA
- lxc: new RA to manage lxc linux containers
- symlink: new RA to manage symbolic links
- VirtualDomain: if there's no config exit with success on stop
- Tools: send_arp: fix the PID file location (bnc#702099)
- iscsi: fix support for open-iscsi version 2.0-872 (lf#2562)
- pgsql: don't check directories on probes
- db2: new implementation with master/slave mode
- exportfs: backup and restore rmtab to ensure smooth client
  failover on node failures
- CTDB: Allow stop to succeed when using pkill on ctdbd (bnc#695829)
- CTDB: Use op timeout when invoking ctdb client (bnc#697428)
- CTDB: Use 'chmod' instead of 'ctdb enablescript' (bnc#697152)
- mysql: --skip-slave-start option is default now
- mysql: set connect timeout to 10 seconds rather than 1 second
- mysql: keep replication state (prevents data loss on master reset)
- mysql: don't rely on state information from pacemaker, but
  check if the instance is in the read-only mode
- mysql: if test parameters are all set, assume OCF_CHECK_LEVEL=10
- mysql: support for master/slave for more than two nodes
- mysql: don't wait for replication to finish, when not replicating
- mysql: store replication state in separate attributes for each master
- pgsql: improve configuration check and probe handling
- VirtualDomain: correctly create migration URI when target is an FQDN
- VirtualDomain: properly wait until domain_name is non-empty
- ldirectord: add a support of "netmask" directive for IPv6
- ldirectord: fix fwmark behavior for IPv6
- ldirectord: ignore children in Net::DNS
- iscsi: add support for open-iscsi version 2.0-872 (lf#2562)
- postfix: issue error if 'postfix abort' failed
- postfix: improve exit codes on installation problems
- postfix: use monitor to test if postfix works after the start action
- ocft: fix make command for compatibility with mawk/Debian (lf#2600)
- ocft: test case for pgsql
- ocft: test case for postfix
- ocft: test case for iscsi
- ocft: new testcases for db2, Filesystem, and LVM
- doc: add man page for sfex_init
- doc: improve man pages output
- doc: add examples for master/slave resource agents
- doc: improve legibility of generated man pages
- ocf-tester: tolerate OCF_ERR_INSTALLED on probes and missing binaries
- update spec file to match the new autoconf setup
- add OCF_ROOT/lib/heartbeat directory for ocf-shellfuncs et al
- remove compatibility scripts /usr/lib/heartbeat/ocf-*
- oracle: improve oracle process list test (bnc#673027)
- upstream cs: 957d32 (v3.9.2)
* Fri Aug  5 2011 tserong@novell.com
- Fix rpmlint non-ghost-in-var-run check
- ldirectord: Remove usage of /var/lock/subsys in init script
* Wed Feb 16 2011 ro@suse.de
- change Conflicts/Obsoletes for now dropped heartbeat subpackages
  to Provides/Obsoletes
* Wed Feb  9 2011 tserong@novell.com
- SAPDatabase: Avoid continuous output to syslog in monitor with SAP
  7.20 and J2EE_ONLY=1
- SAPInstance,SAPDatabase: remove unnecessary usage of eval to start processes
- SAPInstance,SAPDatabase: Allow blanks in path of userexit script
- Add GPLv3 license file (bnc#655700)
- Xen: implement stop of a migrating domain (bnc#656227)
- tomcat: Use here-documents to simplify start/stop operations
- tomcat: Ensure name of tomcat resource is only used on start operation
  and expose JAVA_OPTS variable for use
- tomcat: Fix to ensure default OCF_RESKEY_xx values are observed
- tomcat: Add CATALINA_BASE parameter, defaults to CATALINA_HOME,
  permits multiple tomcat instances
- tomcat: Use Tomcat stop TIMEOUT -force to improve stop
- Dummy: migrate_from/to: correct OCF_RESKEY_CRM_meta_migrate_xxx
  variable names
- Dummy: make method reload work
- IPaddr2: Fix reference to Infiniband arping binary (bnc#668447)
- Upstream version cs: 41cd73a9dedb
* Wed Feb  9 2011 tserong@novell.com
- Fix perl-Net-SSLeay prerequisite
* Tue Feb  8 2011 tserong@novell.com
- ocf-shellfuncs: allow ocf_run to return the actual exit code
- build: install jboss
- nginx: new RA
- LVM: add partial_activation parameter (lf#2490)
- Filesystem: allow cloning of some filesystems as read-only (lf#2440)
- Filesystem: add fast_stop parameter (lf#2402)
- sfex: output log messages also to stderr in sfex_init
- sfex: add the sfex_stat command
- Xen: check the allow_mem_management boolean properly (bnc#637525)
- MailTo: don't check if user exists for email address (might be
  an alias or remote)
- CTDB: Remove hard-coded timeout on start op
- CTDB: Don't manage Samba and Winbind by default
- IPaddr2: optionally flush kernel routing table on interface stop
- IPaddr2: exit with the right code when not properly configured
- IPsrcaddr: exit with the right code when not properly configured
- Tools: findif: differentiate between error conditions
- exportfs: add unlock_on_stop parameter
- exportfs: ensure graceful failover with NFSv4 clients
- exportfs: correctly test for lease time file
- ManageVE: add migration capability
- anything: add the workdir parameter
- pgsql: cd to pgdata before running commands (fixes permission error)
- pgsql: add optional username, password, and sqlcode parameters for monitor
- db2: Replace call to db2_local_ps with db2nps
- db2: guard against a hanging db2stop by spawning this into the
  background. Use db2_kill after grace period.
- db2: add multi partition support
- SAPDatabase,SAPInstance: improve LD_LIBRARY_PATH processing (bnc#640026)
- SAPInstance: prevent premature expansion of [:upper:] [:lower:] when
  producing sidadm uid
- SAPInstance: Moved testing of SAP profile directory and START profile
  to a later stage (only when needed), for more robustness
- SAPInstance: fix return codes in probes
- SAPInstance: New parameter: SHUTDOWN_METHOD
- SAPInstance: ensure enqueue failover in monitor_clone on process failure
- SAPDatabase: prevent premature expansion of [:upper:] and [:lower:]
  when producing sidadm/orasid/db2sid uids
- SAPdatabase: Changed Oracle recovery method from "recover automatic
  database" to "end backup"
- SAPDatabase: Adapt process search pattern for DB/2 9.5
- SAPDatabase: start listener only if database processes are found
- ldirectord: http: connect to server instead of protocol (Debian#594958)
- ldirectord: add implicit support for submission RFC4409
- ldirectord: example configuration for a submission virtual service
- ldirectord: Shutdown write-side of client connection after writing has
  finished
- ldirectord: Add RPM Requires perl-IO-Socket-INET6
- Filesystem: Clarify metadata and improve non-clone warning
- IPaddr2: exit early and with the right code if the ip parameter is not
  set
- ocf-shellfuncs: add option -q to ocf_run to suppress verbose logging
- mysql: if appropriate, connect to master on start
- mysql: if appropriate, delete slave config on start
- pgsql: suppress irrelevant output in the monitor operation
- pgsql: postpone getting the socketdir parameter which depends on the
  configuration
- IPaddr2: add missing 5 to the validation string for the multicast MAC
- Xen: Allow node configurable attribute to specify which IP to use for
  live migration (bnc#628735)
- Xen: use xen-list command for status check if available (bnc#628735)
- Xen: use xen-destroy for stop, if available.
* Sat Nov 20 2010 coolo@novell.com
- build against libnet-devel on 11.4
* Mon Aug  9 2010 lmb@novell.com
- mysql: replace the deprecated -O option (bnc#620275)
- mysql: use replication credentials to test the replication status
- ldirectord: Oracle compatibility
- ldirectord: allow underscore in service name
- ocf-shellfuncs: handle properly syslog facility set to none
  (bnc#621818)
- ocf-tester: show output from the agent in case of error
- IPv6addr: interface index in /proc/net/if_inet6 may be longer than 2
  chars (lf#2462)
- Patch for bnc#623788 is now in mainline.
- Upstream version cs d206bc8f1303
* Mon Jul 26 2010 tserong@novell.com
- CTDB: Deprecate (and make optional) smb_private_dir param (bnc#623788)
* Tue Jul  6 2010 lmb@novell.com
- ldirectord: use $1 instead of \1 in pattern replace (bnc#605086)
- VirtualDomain: Fix spurious stop failures
- RA: mysql: Numerous fixes.
- Raid1: Handle stop for failed arrays properly (bnc#618775)
- Raid1: Support attempting to re-add mirrors on deep monitor action
  (bnc#619121)
- sfex: wait in the start and stop actions until sfex_daemon
  starts/exits
- db2: support for v9.x instances (bnc#608952)
- ocf-shellfuncs: correctly identify root by id only (bnc#602312)
- ocf-tester: meta-data also should never be affected by missing
  binaries.
- ocf-tester: Extend to cover initial probe (monitor_0) test.
- Upstream version cs 9475e2f5d8db
* Mon May 10 2010 dmuhamedagic@novell.com
- RA: set the HA_RSCTMP directory to /var/run/resource-agents (lf#2378)
- pgsql: add new "config" parameter
- pgsql: properly implement pghost parameter
- High: SAPInstance RA: don't rely on op target rc when monitoring clones (lf#2371)
- upstream version cs a7c0f35916bf
* Mon Apr 26 2010 dmuhamedagic@novell.com
- exportfs: new RA
- mysql: master-slave functionality
- oracle: reduce output from sqlplus to the last line for queries (bnc#567815)
- nfsserver: fix the default string for the notification parameter
- upstream version cs f92935082277
* Tue Apr 20 2010 xwhu@novell.com
- VGs are activated with "--partial". This helps the mirrored LVs.
* Mon Apr 12 2010 dmuhamedagic@novell.com
- VirtualDomain: bail out early if config file can't be read
  during probe (nbc#593988)
- VirtualDomain: spin on define until we definitely have a domain name
- Filesystem: prefer /proc/mounts to /etc/mtab for non-bind mounts (lf#2388)
- upstream version cs b3d16560e966
* Mon Mar 29 2010 dmuhamedagic@novell.com
- build: add the postfix RA
- VirtualDomain: fix incorrect use of __OCF_ACTION
  (the stop operation may timeout otherwise)
- IPaddr2: don't bring the interface down on stop
  (otherwise IPv6 addresses may be removed)
- oracle/oralsnr: improve exit codes if the environment isn't valid
- Route: don't assume that OCF_RESKEY_CRM_meta_clone_node_max is
  set to a number (lf#2375)
- meta-data: improve timeouts in most resource agents
  (reduce the number of warnings by the shell)
- SFEX daemon: fix logging
- ldirectord: fix the configfile default (bnc#589457)
- drbd: fix metadata (bnc#588684)
- mysql: revert wrong patch erroneously included with ocft
- mysql: update defaults to match sle11 installations (bnc#590447)
- upstream version cs 000dd8956ad7
* Mon Mar 15 2010 dmuhamedagic@novell.com
- ocft: fix remote shell
- upstream version cs 72f1ac55e70b
* Tue Mar  9 2010 dmuhamedagic@novell.com
- sfex: don't use pid file (lf#2363,bnc#585416)
- IPsrcaddr: modify the interface route (lf#2367)
* Thu Mar  4 2010 dmuhamedagic@novell.com
- ocft: new RA test suite
* Wed Mar  3 2010 dmuhamedagic@novell.com
- log messages from RAs to stderr if attached to a terminal
- ldirectord: Allow multiple email addresses (lf#2168)
- ocf-shellfuncs: tests to check for clone/ms resources
- vmware: multiple improvements
* Mon Feb 22 2010 dmuhamedagic@novell.com
- upstream version cs: da18e46a1f94
- ocf-shellfuncs: don't output to stderr if using syslog (prevents
  double logging from the RA and lrmd)
* Mon Feb 22 2010 dmuhamedagic@novell.com
- upstream version cs: 44b1ba8c7804
* Mon Feb 22 2010 dmuhamedagic@novell.com
- make sure that OCF_RESKEY_CRM_meta_interval is always defined (lf#2284)
- vmware: fix set_environment() invocation (lf#2342)
- oracle/oralsnr: improve logging
- apache: return the right exit code from monitor (bnc#578628)
- iSCSILogicalUnit: fix monitor for STGT
- Route: add route table parameter (lf#2335)
- build: don't include PACKAGE_NAME in HA_NOARCHBIN
* Fri Feb  5 2010 dmuhamedagic@novell.com
- upstream version cs: f40d03a863f1
* Wed Jan 27 2010 lmb@novell.com
- Use same replacement syntax as for other packages.
* Fri Jan 22 2010 dmuhamedagic@novell.com
- upstream version cs: 39b26d5af509
- portblock: fast reconnect/tickle ACK (new resource agent)
- ClusterMon: don't fail in stop if the process is missing (bnc#569957)
- CTDB: auto-generate cluster-specific part of smb.conf (LF 2308)
- doc: add a "see also" link to resource agent man pages
* Tue Jan 19 2010 lmb@novell.com
- Correct dependencies of ldirectord package (bnc#571825).
* Mon Dec 28 2009 dmuhamedagic@novell.com
- add %%dir /usr/share/resource-agents to .spec
* Mon Dec 28 2009 dmuhamedagic@novell.com
- Upstream version cd: b10ad6afb1bd
- mark obsolete RAs as deprecated (LF 2244)
- VirtualDomain: fix forceful stop (LF 2283)
- IPaddr2: CLUSTERIP/iptables rule not always
  inserted on failed monitor (LF 2281)
- copy specfile from upstream
* Mon Dec 14 2009 lmb@novell.com
- Removed wrong conflicts.
* Thu Dec 10 2009 "lmb@novell.com"
- CTDB: New resource agent for clustered samba.
- proftpd: new resource agent.
- Upstream version cs: 520d53bd91dc
* Tue Dec  8 2009 "lmb@novell.com"
- Filesystem: allow configuring smbfs mounts as clones.
- Filesystem: implement deep monitor operation.
- IPaddr2: behave if the interface is down (lf#2147)
- IPaddr2: check binaries when it makes sense
- IPaddr2: fix nvalid default value for OCF_RESKEY_clusterip_hash
  (bnc#553753)
- IPv6addr: recognize network masks properly
- LVM: Make monitor operation quiet in logs (bnc#546353)
- MailTo: Provide a default for MAILCMD (bnc#534803, bnc#556366)
- MailTo: allow multiple word subject line
- Raid1: Improve monitor function (bnc#546551)
- VIParip: Pathname needed to be configurable (lf#1331)
- VirtualDomain: avoid needlessly invoking "virsh define"
- VirtualDomain: loop on status if libvirtd is unreachable.
- Xen: Remove instance_attribute "allow_migrate" (bnc#539968)
- apache: monitor operation of depth 10 for web applications (lf#2234).
- iSCSITarget, iSCSILogicalUnit: support LIO
- jboss: Added JBoss support.
- ldirectord: fix various bugs in OCF RA (lf#1949)
- mysql: escalate stop to KILL if regular shutdown doesn't work
- nfsserver: exit properly in nfsserver_validate (lf#2173)
- nfsserver: use check_binary properly in validate (lf#2211)
- nfsserver: validate should not check if nfs_shared_infodir exists
  (lf#2219)
- oracle/oralsnr: export variables properly
- oracle: drop spurious output from sqlplus
- pgsql: remove the previous backup_label if it exists
- postfix: fix double stop
- vmware: make meta-data work and several cleanups (lf#2212)
- Upstream version cs: 002038be601b
* Tue Sep 15 2009 "lmb@novell.com"
- Revert to SLE HA 11 naming scheme.
- iSCSILogicalUnit: use a 16-byte default SCSI ID.
- iSCSITarget: be more persistent deleting targets on stop.
- portblock: add per-IP filtering capability.
- mysql-proxy: new instance parameters supported.
- Upstream version cs: cde070764e1f
* Thu Aug 27 2009 lmb@novell.com
- IPaddr2: include netmask in search for the right interface
- IPaddr2: remove all colons from the mac address before passing it to
  send_arp (LF#2165)
- IPsrcaddr: replace 0/0 with proper ip prefix.
- IPv6addr: new nic and cidr_netmask parameters
- IPv6addr: supply checksum for ICMPv6 packets
- SAPDatabase + SAPInstance: New versions from SAP.
- Squid: make the regexp match more precisely output of netstat
- VirtualDomain: destroy domain shortly before timeout expiry
- apache: make sure that proxies are not used for monitor
- iSCSILogicalUnit: add support for SCSI ID, SCSI SN, Vendor ID, and
  Product ID
- iSCSILogicalUnit: add support for per-LU parameters
- iSCSILogicalUnit: set default for SCSI SN, truncate SCSI ID default to
  24 bytes
- iSCSITarget, iSCSILogicalUnit: add support for tgt
- iSCSITarget, iSCSILogicalUnit: identify targets by IQN, not by tid
- iSCSITarget: add support for CHAP authentication
- iSCSITarget: add support for restricting target access
- iscsi: replace wrong variable reference (bnc#499291)
- portblock: fix invalid exit codes on monitor
- postfix: new agent.
- Upstream version cs: 9700f962ce0a
* Thu Aug 13 2009 lmb@novell.com
- Include ldirectord (formerly known as heartbeat-ldirectord).
- Upstream version cs: 1263ac948158
* Thu Aug 13 2009 lmb@novell.com
- Obsolete heartbeat-resources package.
* Wed Jul 29 2009 abeekhof@suse.de
- Initial import of the resource-agents project after being split off
  from Heartbeat (this package replaces heartbeat-resources).
- Upstream version cs: 3aa338887920
